<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );}

/**
 * ------------------------------------------------------------------------------------------------
 * Enqueue admin scripts
 * ------------------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'cheshalo_admin_scripts' ) ) {
	function cheshalo_admin_scripts() {
		$version = cheshalo_get_theme_info( 'Version' );

		wp_enqueue_script( 'cheshalo-admin-scripts', CHESHALO_ASSETS . '/js/admin.js', array(), $version, true );
		wp_enqueue_script( 'cheshalo-admin-options', CHESHALO_ASSETS . '/js/options.js', array(), $version, true );

		$std_fonts         = cheshalo_get_config( 'standard-fonts' );
		$custom_fonts_data = cheshalo_get_opt( 'multi_custom_fonts' );
		$custom_fonts      = array();
		if ( isset( $custom_fonts_data['{{index}}'] ) ) {
			unset( $custom_fonts_data['{{index}}'] );
		}

		if ( is_array( $custom_fonts_data ) ) {
			foreach ( $custom_fonts_data as $font ) {
				if ( ! $font['font-name'] ) {
					continue;
				}

				$custom_fonts[ $font['font-name'] ] = $font['font-name'];
			}
		}

		$typekit_fonts = cheshalo_get_opt( 'typekit_fonts' );

		if ( $typekit_fonts ) {
			$typekit = explode( ',', $typekit_fonts );
			foreach ( $typekit as $font ) {
				$custom_fonts[ ucfirst( trim( $font ) ) ] = trim( $font );
			}
		}

		wp_localize_script(
			'cheshalo-admin-options',
			'xtsTypography',
			array(
				'stdfonts'    => $std_fonts,
				'googlefonts' => XTS\Google_Fonts::$all_google_fonts,
				'customFonts' => $custom_fonts,
			)
		);

		if ( apply_filters( 'cheshalo_gradients_enabled', true ) ) {
			wp_enqueue_script( 'cheshalo-colorpicker-scripts', CHESHALO_ASSETS . '/js/colorpicker.min.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-gradient-scripts', CHESHALO_ASSETS . '/js/gradX.min.js', array(), $version, true );
		}

		if ( cheshalo_get_opt( 'size_guides' ) ) {
			wp_enqueue_script( 'cheshalo-edittable-scripts', CHESHALO_ASSETS . '/js/jquery.edittable.min.js', array(), $version, true );
		}

		// Slider
		wp_enqueue_script( 'jquery-ui-slider' );

		// Datepicker
		if ( ! isset( $_GET['page'] ) || ( isset( $_GET['page'] ) && 'rp_wcdpd_settings' !== $_GET['page'] ) ) {
			wp_enqueue_script( 'jquery-ui-datepicker' );
			wp_enqueue_script( 'jquery-datetimepicker', CHESHALO_ASSETS . '/js/datetimepicker.min.js', array(), $version, true );
		}

		// VC Fields
		if ( 'wpb' === cheshalo_get_current_page_builder() ) {
			wp_enqueue_script( 'cheshalo-image-hotspot', CHESHALO_ASSETS . '/js/vc-fields/image-hotspot.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-title-divider', CHESHALO_ASSETS . '/js/vc-fields/title-divider.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-slider', CHESHALO_ASSETS . '/js/vc-fields/slider.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-responsive-size', CHESHALO_ASSETS . '/js/vc-fields/responsive-size.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-vc-image-select', CHESHALO_ASSETS . '/js/vc-fields/image-select.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-vc-colorpicker', CHESHALO_ASSETS . '/js/vc-fields/colorpicker.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-vc-datepicker', CHESHALO_ASSETS . '/js/vc-fields/datepicker.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-vc-switch', CHESHALO_ASSETS . '/js/vc-fields/switch.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-vc-button-set', CHESHALO_ASSETS . '/js/vc-fields/button-set.js', array(), $version, true );
			wp_enqueue_script( 'cheshalo-vc-functions', CHESHALO_ASSETS . '/js/vc-fields/vc-functions.js', array(), $version, true );
		}

		cheshalo_admin_scripts_localize();
	}

	add_action( 'admin_init', 'cheshalo_admin_scripts', 100 );
}

if ( ! function_exists( 'cheshalo_frontend_editor_enqueue_scripts' ) ) {
	function cheshalo_frontend_editor_enqueue_scripts() {
		$version = cheshalo_get_theme_info( 'Version' );
		cheshalo_enqueue_js_library( 'cookie' );
		wp_enqueue_script( 'cheshalo-frontend-editor-functions', CHESHALO_ASSETS . '/js/vc-fields/frontend-editor-functions.js', array(), $version, true );
	}

	add_action( 'vc_frontend_editor_enqueue_js_css', 'cheshalo_frontend_editor_enqueue_scripts', 100 );
}

/**
 * ------------------------------------------------------------------------------------------------
 * Localize admin script function
 * ------------------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'cheshalo_admin_scripts_localize' ) ) {
	function cheshalo_admin_scripts_localize() {
		wp_localize_script( 'cheshalo-admin-scripts', 'cheshaloConfig', cheshalo_admin_script_local() );
	}
}


/**
 * ------------------------------------------------------------------------------------------------
 * Get localization array for admin scripts
 * ------------------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'cheshalo_admin_script_local' ) ) {
	function cheshalo_admin_script_local() {
		$localize_data = array(
			'ajax'                             => admin_url( 'admin-ajax.php' ),
			'get_builder_elements_nonce'       => wp_create_nonce( 'cheshalo-get-builder-elements-nonce' ),
			'get_builder_element_nonce'        => wp_create_nonce( 'cheshalo-get-builder-element-nonce' ),
			'builder_load_header_nonce'        => wp_create_nonce( 'cheshalo-builder-load-header-nonce' ),
			'builder_save_header_nonce'        => wp_create_nonce( 'cheshalo-builder-save-header-nonce' ),
			'builder_remove_header_nonce'      => wp_create_nonce( 'cheshalo-builder-remove-header-nonce' ),
			'builder_set_default_header_nonce' => wp_create_nonce( 'cheshalo-builder-set-default-header-nonce' ),
			'import_nonce'                     => wp_create_nonce( 'cheshalo-import-nonce' ),
			'mega_menu_added_thumbnail_nonce'  => wp_create_nonce( 'cheshalo-mega-menu-added-thumbnail-nonce' ),
			'get_hotspot_image_nonce'          => wp_create_nonce( 'cheshalo-get-hotspot-image-nonce' ),
		);

		// If we are on edit product attribute pages
		if ( ! empty( $_GET['page'] ) && $_GET['page'] == 'product_attributes' && ! empty( $_GET['edit'] ) && function_exists( 'wc_attribute_taxonomy_name_by_id' ) ) {
			$attribute_id   = sanitize_text_field( wp_unslash( $_GET['edit'] ) ); // phpcs:ignore
			$taxonomy_ids                            = wc_get_attribute_taxonomy_ids();
			$attribute_name                          = array_search( $attribute_id, $taxonomy_ids, false );
			$localize_data['attributeSwatchSize']    = cheshalo_wc_get_attribute_term( 'pa_' . $attribute_name, 'swatch_size' );
			$localize_data['attributeShowOnProduct'] = cheshalo_wc_get_attribute_term( 'pa_' . $attribute_name, 'show_on_product' );
		}

		$all_fields   = XTS\Options::get_fields();
		$all_sections = XTS\Options::get_sections();

		$options_data = array();
		foreach ( $all_fields as $field ) {
			$path       = '';
			$section_id = $field->args['section'];
			$section    = $all_sections[ $section_id ];

			if ( isset( $section['parent'] ) ) {
				$path = $all_sections[ $section['parent'] ]['name'] . ' -> ' . $section['name'];
			} else {
				$path = $section['name'];
			}

			$text = isset( $field->args['name'] ) ? $field->args['name'] : '';
			if ( isset( $field->args['description'] ) ) {
				$text .= ' ' . $field->args['description'];
			}
			if ( isset( $field->args['tags'] ) ) {
				$text .= ' ' . $field->args['tags'];
			}

			$options_data[] = array(
				'id'         => $field->args['id'],
				'title'      => isset( $field->args['name'] ) ? $field->args['name'] : '',
				'text'       => $text,
				'section_id' => $section['id'],
				'icon'       => isset( $section['icon'] ) ? $section['icon'] : $all_sections[ $section['parent'] ]['icon'],
				'path'       => $path,
			);
		}

		$localize_data['xtsOptions'] = $options_data;

		$localize_data['searchOptionsPlaceholder']              = esc_js( __( 'Search for options', 'cheshalo' ) );
		$localize_data['ajaxUrl']                               = admin_url( 'admin-ajax.php' );
		$localize_data['demoAjaxUrl']                           = CHESHALO_DEMO_URL . 'wp-admin/admin-ajax.php';
		$localize_data['activate_plugin_btn_text']              = esc_html__( 'Activate', 'cheshalo' );
		$localize_data['update_plugin_btn_text']                = esc_html__( 'Update', 'cheshalo' );
		$localize_data['deactivate_plugin_btn_text']            = esc_html__( 'Deactivate', 'cheshalo' );
		$localize_data['install_plugin_btn_text']               = esc_html__( 'Install', 'cheshalo' );
		$localize_data['activate_process_plugin_btn_text']      = esc_html__( 'Activating', 'cheshalo' );
		$localize_data['update_process_plugin_btn_text']        = esc_html__( 'Updating', 'cheshalo' );
		$localize_data['deactivate_process_plugin_btn_text']    = esc_html__( 'Deactivating', 'cheshalo' );
		$localize_data['install_process_plugin_btn_text']       = esc_html__( 'Installing', 'cheshalo' );
		$localize_data['attribute_swatch_size_title']           = esc_html__( 'Attributes swatch size', 'cheshalo' );
		$localize_data['attribute_swatch_size_description']     = esc_html__( 'If you will set color or images swatches for terms of this attribute.', 'cheshalo' );
		$localize_data['attribute_show_on_product_title']       = esc_html__( 'Show attribute label on products', 'cheshalo' );
		$localize_data['attribute_show_on_product_description'] = esc_html__( 'Enable this if you want to show this attribute label on products in your store.', 'cheshalo' );

		return apply_filters( 'cheshalo_admin_script_local', $localize_data );
	}
}


/**
 * ------------------------------------------------------------------------------------------------
 * Enqueue admin styles
 * ------------------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'cheshalo_enqueue_admin_styles' ) ) {
	function cheshalo_enqueue_admin_styles() {
		$version = cheshalo_get_theme_info( 'Version' );
		if ( is_admin() ) {
			wp_enqueue_style( 'cheshalo-admin-style', CHESHALO_ASSETS . '/css/theme-admin.css', array(), $version );

			if ( apply_filters( 'cheshalo_gradients_enabled', true ) ) {
				wp_enqueue_style( 'cheshalo-colorpicker-style', CHESHALO_ASSETS . '/css/colorpicker.css', array(), $version );
				wp_enqueue_style( 'cheshalo-gradient-style', CHESHALO_ASSETS . '/css/gradX.css', array(), $version );
			}
			if ( cheshalo_get_opt( 'size_guides' ) ) {
				wp_enqueue_style( 'cheshalo-edittable-style', CHESHALO_ASSETS . '/css/jquery.edittable.min.css', array(), $version );
			}

			wp_enqueue_style( 'cheshalo-jquery-ui', CHESHALO_ASSETS . '/css/jquery-ui.css', array(), $version );
		}

	}

	add_action( 'admin_enqueue_scripts', 'cheshalo_enqueue_admin_styles' );
}

