<?php
/**
 * Page metaboxes
 *
 * @package xts
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

use XTS\Metaboxes;

if ( ! function_exists( 'cheshalo_register_page_metaboxes' ) ) {
	/**
	 * Register page metaboxes
	 *
	 * @since 1.0.0
	 */
	function cheshalo_register_page_metaboxes() {
		global $cheshalo_transfer_options, $cheshalo_prefix;

		$cheshalo_prefix = '_cheshalo_';

		$page_metabox = Metaboxes::add_metabox(
			array(
				'id'         => 'xts_page_metaboxes',
				'title'      => esc_html__( 'Page Setting (custom metabox from theme)', 'cheshalo' ),
				'post_types' => array( 'page', 'post', 'portfolio' ),
			)
		);

		$page_metabox->add_section(
			array(
				'id'       => 'general',
				'name'     => esc_html__( 'General', 'cheshalo' ),
				'priority' => 10,
				'icon'     => CHESHALO_ASSETS . '/assets/images/dashboard-icons/settings.svg',
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'whb_header',
				'name'        => esc_html__( 'Custom header for this page', 'cheshalo' ),
				'description' => esc_html__( 'If you are using our header builder for your header configuration you can select different layout from the list for this particular page.', 'cheshalo' ),
				'group'       => esc_html__( 'Header options', 'cheshalo' ),
				'type'        => 'select',
				'section'     => 'general',
				'options'     => cheshalo_get_whb_headers_array( true, true ),
				'default'     => 'inherit',
				'priority'    => 10,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'open_categories',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Open categories menu', 'cheshalo' ),
				'description' => esc_html__( 'Always shows categories navigation on this page', 'cheshalo' ),
				'group'       => esc_html__( 'Header options', 'cheshalo' ),
				'section'     => 'general',
				'priority'    => 20,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'title_off',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Disable Page title', 'cheshalo' ),
				'description' => esc_html__( 'You can hide page heading for this page', 'cheshalo' ),
				'group'       => esc_html__( 'Page title options', 'cheshalo' ),
				'section'     => 'general',
				'priority'    => 30,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'title_image',
				'type'        => 'upload',
				'name'        => esc_html__( 'Image for page title', 'cheshalo' ),
				'description' => esc_html__( 'Upload an image', 'cheshalo' ),
				'group'       => esc_html__( 'Page title options', 'cheshalo' ),
				'section'     => 'general',
				'data_type'   => 'url',
				'priority'    => 40,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'title_bg_color',
				'type'        => 'color',
				'name'        => esc_html__( 'Page title background color', 'cheshalo' ),
				'description' => esc_html__( 'Сhoose a color', 'cheshalo' ),
				'group'       => esc_html__( 'Page title options', 'cheshalo' ),
				'section'     => 'general',
				'data_type'   => 'hex',
				'priority'    => 50,
			)
		);

		$page_metabox->add_field(
			array(
				'id'       => $cheshalo_prefix . 'title_color',
				'name'     => esc_html__( 'Text color for title', 'cheshalo' ),
				'group'    => esc_html__( 'Page title options', 'cheshalo' ),
				'type'     => 'buttons',
				'section'  => 'general',
				'options'  => array(
					'default' => array(
						'name'  => esc_html__( 'Inherit', 'cheshalo' ),
						'value' => 'default',
					),
					'light'   => array(
						'name'  => esc_html__( 'Light', 'cheshalo' ),
						'value' => 'light',
					),
					'dark'    => array(
						'name'  => esc_html__( 'Dark', 'cheshalo' ),
						'value' => 'dark',
					),
				),
				'default'  => 'default',
				'priority' => 60,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'page-title-size',
				'name'        => esc_html__( 'Page title size' ),
				'description' => esc_html__( 'You can set different sizes for your page titles.', 'cheshalo' ),
				'group'       => esc_html__( 'Page title options', 'cheshalo' ),
				'type'        => 'buttons',
				'section'     => 'general',
				'options'     => array(
					'inherit' => array(
						'name'  => esc_html__( 'Inherit', 'cheshalo' ),
						'value' => 'inherit',
					),
					'default' => array(
						'name'  => esc_html__( 'Default', 'cheshalo' ),
						'value' => 'default',
					),
					'small'   => array(
						'name'  => esc_html__( 'Small', 'cheshalo' ),
						'value' => 'small',
					),
					'large'   => array(
						'name'  => esc_html__( 'Large', 'cheshalo' ),
						'value' => 'large',
					),
				),
				'default'     => 'inherit',
				'priority'    => 70,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'main_layout',
				'name'        => esc_html__( 'Sidebar position', 'cheshalo' ),
				'description' => esc_html__( 'Select main content and sidebar alignment.', 'cheshalo' ),
				'group'       => esc_html__( 'Sidebar options', 'cheshalo' ),
				'type'        => 'buttons',
				'section'     => 'general',
				'options'     => array(
					'default'       => array(
						'name'  => esc_html__( 'Inherit', 'cheshalo' ),
						'value' => 'default',
					),
					'full-width'    => array(
						'name'  => esc_html__( 'Without', 'cheshalo' ),
						'value' => 'full-width',
					),
					'sidebar-left'  => array(
						'name'  => esc_html__( 'Left', 'cheshalo' ),
						'value' => 'sidebar-left',
					),
					'sidebar-right' => array(
						'name'  => esc_html__( 'Right', 'cheshalo' ),
						'value' => 'sidebar-right',
					),
				),
				'default'     => 'default',
				'priority'    => 80,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'sidebar_width',
				'name'        => esc_html__( 'Sidebar size', 'cheshalo' ),
				'description' => esc_html__( 'You can set different sizes for your pages sidebar', 'cheshalo' ),
				'group'       => esc_html__( 'Sidebar options', 'cheshalo' ),
				'type'        => 'buttons',
				'section'     => 'general',
				'options'     => array(
					'default' => array(
						'name'  => esc_html__( 'Inherit', 'cheshalo' ),
						'value' => 'default',
					),
					2         => array(
						'name'  => esc_html__( 'Small', 'cheshalo' ),
						'value' => 2,
					),
					3         => array(
						'name'  => esc_html__( 'Medium', 'cheshalo' ),
						'value' => 3,
					),
					4         => array(
						'name'  => esc_html__( 'Large', 'cheshalo' ),
						'value' => 4,
					),
				),
				'default'     => 'default',
				'priority'    => 90,
			)
		);

		$cheshalo_transfer_options[] = 'page-title-size';
		$cheshalo_transfer_options[] = 'main_layout';
		$cheshalo_transfer_options[] = 'sidebar_width';

		$page_metabox->add_field(
			array(
				'id'       => $cheshalo_prefix . 'custom_sidebar',
				'name'     => esc_html__( 'Custom sidebar for this page', 'cheshalo' ),
				'group'    => esc_html__( 'Sidebar options', 'cheshalo' ),
				'type'     => 'select',
				'section'  => 'general',
				'options'  => '',
				'callback' => 'cheshalo_get_theme_settings_sidebars_array',
				'priority' => 100,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'footer_off',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Disable footer', 'cheshalo' ),
				'description' => esc_html__( 'You can disable footer for this page', 'cheshalo' ),
				'group'       => esc_html__( 'Footer options', 'cheshalo' ),
				'section'     => 'general',
				'priority'    => 110,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'prefooter_off',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Disable prefooter', 'cheshalo' ),
				'description' => esc_html__( 'You can disable prefooter for this page', 'cheshalo' ),
				'group'       => esc_html__( 'Footer options', 'cheshalo' ),
				'section'     => 'general',
				'priority'    => 120,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'copyrights_off',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Disable copyrights', 'cheshalo' ),
				'description' => esc_html__( 'You can disable copyrights for this page', 'cheshalo' ),
				'group'       => esc_html__( 'Footer options', 'cheshalo' ),
				'section'     => 'general',
				'priority'    => 130,
			)
		);
	}

	add_action( 'init', 'cheshalo_register_page_metaboxes', 100 );
}


$post_category_metabox = Metaboxes::add_metabox(
	array(
		'id'         => 'xts_post_category_metaboxes',
		'title'      => esc_html__( 'Extra options from theme', 'cheshalo' ),
		'object'     => 'term',
		'taxonomies' => array( 'category' ),
	)
);

$post_category_metabox->add_section(
	array(
		'id'       => 'general',
		'name'     => esc_html__( 'General', 'cheshalo' ),
		'icon'     => CHESHALO_ASSETS . '/assets/images/dashboard-icons/settings.svg',
		'priority' => 10,
	)
);

$post_category_metabox->add_field(
	array(
		'id'          => '_cheshalo_blog_design',
		'name'        => esc_html__( 'Blog Design', 'cheshalo' ),
		'description' => esc_html__( 'Choose one of the blog designs available in the theme.', 'cheshalo' ),
		'type'        => 'select',
		'section'     => 'general',
		'options'     => array(
			'inherit'      => array(
				'name'  => esc_html__( 'Inherit', 'cheshalo' ),
				'value' => 'inherit',
			),
			'default'      => array(
				'name'  => esc_html__( 'Default', 'cheshalo' ),
				'value' => 'Default',
			),
			'default-alt'  => array(
				'name'  => esc_html__( 'Default alternative', 'cheshalo' ),
				'value' => 'default-alt',
			),
			'small-images' => array(
				'name'  => esc_html__( 'Small images', 'cheshalo' ),
				'value' => 'small-images',
			),
			'chess'        => array(
				'name'  => esc_html__( 'Chess', 'cheshalo' ),
				'value' => 'chess',
			),
			'masonry'      => array(
				'name'  => esc_html__( 'Masonry grid', 'cheshalo' ),
				'value' => 'default',
			),
			'mask'         => array(
				'name'  => esc_html__( 'Mask on image', 'cheshalo' ),
				'value' => 'mask',
			),
			'meta-image'   => array(
				'name'  => esc_html__( 'Meta on image', 'cheshalo' ),
				'value' => 'meta-image',
			),
		),
		'priority'    => 10,
	)
);
