<?php
if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
}

use XTS\Options;

Options::add_field(
	array(
		'id'          => 'blog_layout',
		'name'        => esc_html__( 'Blog Layout', 'cheshalo' ),
		'description' => esc_html__( 'Select main content and sidebar alignment for blog pages.', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_section',
		'options'     => array(
			'full-width'    => array(
				'name'  => esc_html__( '1 Column', 'cheshalo' ),
				'value' => 'full-width',
				'image' => CHESHALO_ASSETS_IMAGES . '/settings/sidebar-layout/none.png',
			),
			'sidebar-left'  => array(
				'name'  => esc_html__( '2 Columns Left', 'cheshalo' ),
				'value' => 'sidebar-left',
				'image' => CHESHALO_ASSETS_IMAGES . '/settings/sidebar-layout/left.png',
			),
			'sidebar-right' => array(
				'name'  => esc_html__( '2 Columns Right', 'cheshalo' ),
				'value' => 'sidebar-right',
				'image' => CHESHALO_ASSETS_IMAGES . '/settings/sidebar-layout/right.png',
			),
		),
		'default'     => 'sidebar-right',
		'priority'    => 10,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_sidebar_width',
		'name'        => esc_html__( 'Blog Sidebar size', 'cheshalo' ),
		'description' => esc_html__( 'You can set different sizes for your blog pages sidebar', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_section',
		'options'     => array(
			2 => array(
				'name'  => esc_html__( 'Small', 'cheshalo' ),
				'value' => 2,
			),
			3 => array(
				'name'  => esc_html__( 'Medium', 'cheshalo' ),
				'value' => 2,
			),
			4 => array(
				'name'  => esc_html__( 'Large', 'cheshalo' ),
				'value' => 2,
			),
		),
		'default'     => 3,
		'priority'    => 20,
	)
);

Options::add_field(
	array(
		'id'          => 'single_post_justified_gallery',
		'name'        => esc_html__( 'Justify gallery', 'cheshalo' ),
		'description' => esc_html__( 'This option will replace standard WordPress gallery with "Justified gallery" JS library.', 'cheshalo' ),
		'type'        => 'switcher',
		'section'     => 'blog_section',
		'default'     => '0',
		'priority'    => 30,
	)
);

/**
 * Blog archive.
 */
Options::add_field(
	array(
		'id'          => 'blog_design',
		'name'        => esc_html__( 'Blog Design', 'cheshalo' ),
		'description' => esc_html__( 'Choose one of the blog designs available in the theme.', 'cheshalo' ),
		'type'        => 'select',
		'section'     => 'blog_archive_section',
		'options'     => array(
			'default'      => array(
				'name'  => esc_html__( 'Default', 'cheshalo' ),
				'value' => 'default',
			),
			'default-alt'  => array(
				'name'  => esc_html__( 'Default alternative', 'cheshalo' ),
				'value' => 'default-alt',
			),
			'small-images' => array(
				'name'  => esc_html__( 'Small images', 'cheshalo' ),
				'value' => 'small-images',
			),
			'chess'        => array(
				'name'  => esc_html__( 'Chess', 'cheshalo' ),
				'value' => 'chess',
			),
			'masonry'      => array(
				'name'  => esc_html__( 'Masonry grid', 'cheshalo' ),
				'value' => 'masonry',
			),
			'mask'         => array(
				'name'  => esc_html__( 'Mask on image', 'cheshalo' ),
				'value' => 'mask',
			),
			'meta-image'   => array(
				'name'  => esc_html__( 'Meta on image', 'cheshalo' ),
				'value' => 'meta-image',
			),
		),
		'default'     => 'masonry',
		'priority'    => 10,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_style',
		'name'        => esc_html__( 'Blog Style', 'cheshalo' ),
		'description' => esc_html__( 'You can use flat style or add a shadow to your blog posts.', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_archive_section',
		'options'     => array(
			'flat'   => array(
				'name'  => esc_html__( 'Flat', 'cheshalo' ),
				'value' => 'flat',
			),
			'shadow' => array(
				'name'  => esc_html__( 'With shadow', 'cheshalo' ),
				'value' => 'shadow',
			),
		),
		'requires'    => array(
			array(
				'key'     => 'blog_design',
				'compare' => 'not_equals',
				'value'   => array( 'meta-image' ),
			),
		),
		'default'     => 'shadow',
		'priority'    => 20,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_columns',
		'name'        => esc_html__( 'Blog items columns', 'cheshalo' ),
		'description' => esc_html__( 'Number of columns for the blog grid.', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_archive_section',
		'options'     => array(
			2 => array(
				'name'  => 2,
				'value' => 2,
			),
			3 => array(
				'name'  => 3,
				'value' => 3,
			),
			4 => array(
				'name'  => 4,
				'value' => 4,
			),
		),
		'default'     => 3,
		'priority'    => 30,
		'requires'    => array(
			array(
				'key'     => 'blog_design',
				'compare' => 'equals',
				'value'   => array( 'masonry', 'mask', 'meta-image' ),
			),
		),
	)
);

Options::add_field(
	array(
		'id'          => 'blog_spacing',
		'name'        => esc_html__( 'Space between posts', 'cheshalo' ),
		'description' => esc_html__( 'You can set the different spacing between posts on the blog page.', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_archive_section',
		'options'     => array(
			0  => array(
				'name'  => 0,
				'value' => 0,
			),
			2  => array(
				'name'  => 2,
				'value' => 2,
			),
			6  => array(
				'name'  => 5,
				'value' => 6,
			),
			10 => array(
				'name'  => 10,
				'value' => 10,
			),
			20 => array(
				'name'  => 20,
				'value' => 20,
			),
			30 => array(
				'name'  => 30,
				'value' => 30,
			),
		),
		'default'     => 20,
		'priority'    => 40,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_pagination',
		'name'        => esc_html__( 'Blog pagination', 'cheshalo' ),
		'description' => esc_html__( 'Choose a type for the pagination on your blog page.', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_archive_section',
		'options'     => array(
			'pagination' => array(
				'name'  => esc_html__( 'Pagination links', 'cheshalo' ),
				'value' => 'pagination',
			),
			'load_more'  => array(
				'name'  => esc_html__( '"Load more" button', 'cheshalo' ),
				'value' => 'load_more',
			),
			'infinit'    => array(
				'name'  => esc_html__( 'Infinit scrolling', 'cheshalo' ),
				'value' => 'infinit',
			),
		),
		'default'     => 'pagination',
		'priority'    => 50,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_excerpt',
		'name'        => esc_html__( 'Posts excerpt', 'cheshalo' ),
		'description' => esc_html__( 'If you set this option to "Excerpt" then you would be able to set a custom excerpt for each post or it will be cut from the post content. If you choose "Full content" then all content will be shown, or you can add the "Read more button" while editing the post and by doing this cut your excerpt length as you need.', 'cheshalo' ),
		'group'       => esc_html__( 'Post content', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_archive_section',
		'options'     => array(
			'excerpt' => array(
				'name'  => esc_html__( 'Excerpt', 'cheshalo' ),
				'value' => 'excerpt',
			),
			'full'    => array(
				'name'  => esc_html__( 'Full content', 'cheshalo' ),
				'value' => 'full',
			),
		),
		'default'     => 'full',
		'priority'    => 60,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_words_or_letters',
		'name'        => esc_html__( 'Excerpt length by words or letters', 'cheshalo' ),
		'description' => esc_html__( 'Limit your excerpt text for posts by words or letters.', 'cheshalo' ),
		'group'       => esc_html__( 'Post content', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_archive_section',
		'options'     => array(
			'word'   => array(
				'name'  => esc_html__( 'Word', 'cheshalo' ),
				'value' => 'word',
			),
			'letter' => array(
				'name'  => esc_html__( 'Letters', 'cheshalo' ),
				'value' => 'letter',
			),
		),
		'requires'    => array(
			array(
				'key'     => 'blog_excerpt',
				'compare' => 'equals',
				'value'   => array( 'excerpt' ),
			),
		),
		'default'     => 'letter',
		'priority'    => 70,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_excerpt_length',
		'name'        => esc_html__( 'Excerpt length', 'cheshalo' ),
		'description' => esc_html__( 'Number of words or letters that will be displayed for each post if you use "Excerpt" mode and don\'t set custom excerpt for each post.', 'cheshalo' ),
		'group'       => esc_html__( 'Post content', 'cheshalo' ),
		'type'        => 'text_input',
		'section'     => 'blog_archive_section',
		'requires'    => array(
			array(
				'key'     => 'blog_excerpt',
				'compare' => 'equals',
				'value'   => array( 'excerpt' ),
			),
		),
		'default'     => 135,
		'priority'    => 80,
	)
);

/**
 * Single post.
 */
Options::add_field(
	array(
		'id'          => 'single_post_header',
		'name'        => esc_html__( 'Single post header', 'cheshalo' ),
		'description' => esc_html__( 'You can use different header for your single post page.', 'cheshalo' ),
		'type'        => 'select',
		'section'     => 'blog_singe_post_section',
		'options'     => cheshalo_get_whb_headers_array( true, true ),
		'default'     => 'none',
		'priority'    => 10,
	)
);

Options::add_field(
	array(
		'id'          => 'single_post_design',
		'name'        => esc_html__( 'Single post design', 'cheshalo' ),
		'description' => esc_html__( 'You can use different design for your single post page.', 'cheshalo' ),
		'type'        => 'buttons',
		'section'     => 'blog_singe_post_section',
		'options'     => array(
			'default'     => array(
				'name'  => esc_html__( 'Default', 'cheshalo' ),
				'value' => 'default',
			),
			'large_image' => array(
				'name'  => esc_html__( 'Large image', 'cheshalo' ),
				'value' => 'large_image',
			),
		),
		'default'     => 'default',
		'priority'    => 20,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_share',
		'name'        => esc_html__( 'Share buttons', 'cheshalo' ),
		'description' => esc_html__( 'Display share icons on single post page', 'cheshalo' ),
		'group'       => esc_html__( 'Elements', 'cheshalo' ),
		'type'        => 'switcher',
		'section'     => 'blog_singe_post_section',
		'default'     => '1',
		'class'       => 'xts-col-6',
		'priority'    => 30,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_navigation',
		'name'        => esc_html__( 'Posts navigation', 'cheshalo' ),
		'description' => esc_html__( 'Next and previous posts links on single post page', 'cheshalo' ),
		'group'       => esc_html__( 'Elements', 'cheshalo' ),
		'type'        => 'switcher',
		'section'     => 'blog_singe_post_section',
		'default'     => '1',
		'class'       => 'xts-col-6',
		'priority'    => 40,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_author_bio',
		'name'        => esc_html__( 'Author bio', 'cheshalo' ),
		'description' => esc_html__( 'Display information about the post author', 'cheshalo' ),
		'group'       => esc_html__( 'Elements', 'cheshalo' ),
		'type'        => 'switcher',
		'section'     => 'blog_singe_post_section',
		'default'     => '1',
		'class'       => 'xts-col-6',
		'priority'    => 50,
	)
);

Options::add_field(
	array(
		'id'          => 'blog_related_posts',
		'name'        => esc_html__( 'Related posts', 'cheshalo' ),
		'description' => esc_html__( 'Show related posts on single post page (by tags)', 'cheshalo' ),
		'group'       => esc_html__( 'Elements', 'cheshalo' ),
		'type'        => 'switcher',
		'section'     => 'blog_singe_post_section',
		'default'     => '1',
		'class'       => 'xts-col-6',
		'priority'    => 60,
	)
);
