<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );}

/**
 * Class to work with Theme Options
 * Will modify global $cheshalo_options variable
 */
class CHESHALO_Options {

	public function __construct() {

		$options = get_option( 'cheshalo_options' );


		if ( ! is_admin() ) {

			add_action( 'wp', array( $this, 'set_custom_meta_for_post' ), 500 );
			add_action( 'wp', array( $this, 'set_options_for_post' ), 505 );
			add_action( 'wp', array( $this, 'specific_options' ), 510 );
			add_action( 'wp', array( $this, 'specific_taxonomy_options' ), 515 );
			add_action( 'wp', array( $this, 'specific_taxonomy_options' ), 40 );

		}
	}

	/**
	 * Specific options
	 */
	public function set_options_for_post( $slug = '' ) {
		global $cheshalo_options;

		$custom_options = json_decode( get_post_meta( cheshalo_page_ID(), '_cheshalo_options', true ), true );

		if ( ! empty( $custom_options ) ) {
			$cheshalo_options = wp_parse_args( $custom_options, $cheshalo_options );
		}

		$cheshalo_options = apply_filters( 'cheshalo_global_options', $cheshalo_options );

	}


	/**
	 * [set_custom_meta_for_post description]
	 */
	public function set_custom_meta_for_post( $slug = '' ) {
		global $xts_cheshalo_options, $cheshalo_transfer_options, $cheshalo_prefix;
		if ( ! empty( $cheshalo_transfer_options ) ) {
			foreach ( $cheshalo_transfer_options as $field ) {
				$meta = get_post_meta( cheshalo_page_ID(), $cheshalo_prefix . $field, true );
				if ( isset( $xts_cheshalo_options[ $field ] ) ) {
					$xts_cheshalo_options[ $field ] = ( isset( $meta ) && $meta != '' && $meta != 'inherit' && $meta != 'default' ) ? $meta : $xts_cheshalo_options[ $field ];
				}
			}
		}

	}


	/**
	 * Specific options dependencies
	 */
	public function specific_options( $slug = '' ) {
		global $xts_cheshalo_options;

		$rules = cheshalo_get_config( 'specific-options' );

		foreach ( $rules as $option => $rule ) {
			if ( ! empty( $rule['will-be'] ) && ! isset( $rule['if'] ) ) {
				$xts_cheshalo_options[ $option ] = $rule['will-be'];
			} elseif ( isset( $xts_cheshalo_options[ $rule['if'] ] ) && in_array( $xts_cheshalo_options[ $rule['if'] ], $rule['in_array'] ) ) {
				$xts_cheshalo_options[ $option ] = $rule['will-be'];
			}
		}

	}


	/**
	 * Specific options for taxonomies
	 */
	public function specific_taxonomy_options( $slug = '' ) {
		global $xts_cheshalo_options;

		if ( is_category() ) {
			$option_key       = 'blog_design';
			$category         = get_query_var( 'cat' );
			$current_category = get_category( $category );
			// $current_category->term_id;
			$category_blog_design = get_term_meta( $current_category->term_id, '_cheshalo_' . $option_key, true );

			if ( ! empty( $category_blog_design ) && $category_blog_design != 'inherit' ) {
				$xts_cheshalo_options[ $option_key ] = $category_blog_design;
			}
		}

	}
	
	
	
	/**
	 * Get option from array $cheshalo_options
	 *
	 * @param  String option slug
	 * @return String option value
	 */
	public function get_opt( $slug, $default = false ) {
		global $cheshalo_options, $xts_cheshalo_options;
		
		$opt = $default;

		if ( isset( $xts_cheshalo_options[ $slug ] ) ) {
			$opt = $xts_cheshalo_options[ $slug ];
			return $opt;
		}
		
		if ( isset( $cheshalo_options[ $slug ] ) ) {
			$opt = $cheshalo_options[ $slug ];
			return $opt;
		}

		return $opt;
	}
}

// **********************************************************************//
// ! Function to get option
// **********************************************************************//
if ( ! function_exists( 'cheshalo_get_opt' ) ) {
	function cheshalo_get_opt( $slug = '', $default = false ) {
		return CHESHALO_Registry::getInstance()->options->get_opt( $slug, $default );
	}
}
