<?php
/**
 * Promo banner map.
 */

use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

/**
 * Elementor widget that inserts an embeddable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Banner extends Widget_Base {
	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'wd_banner';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Promo Banner', 'cheshalo' );
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'wd-icon-banner';
	}

	/**
	 * Get widget categories.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'wd-elements' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		/**
		 * Content tab.
		 */

		/**
		 * General settings.
		 */
		$this->start_controls_section(
			'general_content_section',
			[
				'label' => esc_html__( 'General', 'cheshalo' ),
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Link', 'cheshalo' ),
				'description' => esc_html__( 'Enter URL if you want this banner to have a link.', 'cheshalo' ),
				'type'        => Controls_Manager::URL,
				'default'     => [
					'url'         => '#',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->end_controls_section();

		/**
		 * Image settings.
		 */
		$this->start_controls_section(
			'image_content_section',
			[
				'label' => esc_html__( 'Image', 'cheshalo' ),
			]
		);

		$this->add_control(
			'image_type',
			[
				'label'   => esc_html__( 'Display', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'background' => esc_html__( 'As background', 'cheshalo' ),
					'image'      => esc_html__( 'As image', 'cheshalo' ),
				],
				'default' => 'image',
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Choose image', 'cheshalo' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name'      => 'image',
				'default'   => 'thumbnail',
				'separator' => 'none',
			]
		);

		$this->add_responsive_control(
			'image_height',
			[
				'label'     => esc_html__( 'Image height', 'cheshalo' ),
				'type'      => Controls_Manager::SLIDER,
				'default'   => [
					'size' => 300,
				],
				'range'     => [
					'px' => [
						'min'  => 100,
						'max'  => 2000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .banner-image' => 'height: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'image_type' => [ 'background' ],
				],
			]
		);

		$this->add_control(
			'image_bg_position',
			[
				'label'     => esc_html__( 'Background position', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'center center' => esc_html__( 'Center', 'cheshalo' ),
					'center top'    => esc_html__( 'Top', 'cheshalo' ),
					'center bottom' => esc_html__( 'Bottom', 'cheshalo' ),
					'left center'   => esc_html__( 'Left', 'cheshalo' ),
					'right center'  => esc_html__( 'Right', 'cheshalo' ),
				],
				'default'   => 'center center',
				'selectors' => [
					'{{WRAPPER}} .banner-image' => 'background-position: {{VALUE}};',
				],
				'condition' => [
					'image_type' => [ 'background' ],
				],
			]
		);

		$this->end_controls_section();

		/**
		 * Content settings.
		 */
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'cheshalo' ),
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'   => esc_html__( 'Subtitle', 'cheshalo' ),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => 'Banner subtitle text',
			]
		);

		$this->add_control(
			'title',
			[
				'label'   => esc_html__( 'Title', 'cheshalo' ),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => 'Banner title, click to edit.',
			]
		);

		$this->add_control(
			'content',
			[
				'label'   => esc_html__( 'Content', 'cheshalo' ),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => 'Banner content text',
			]
		);

		$this->add_control(
			'btn_text',
			[
				'label'   => esc_html__( 'Button text', 'cheshalo' ),
				'type'    => Controls_Manager::TEXT,
				'default' => 'Read more',
			]
		);

		$this->end_controls_section();

		/**
		 * Style tab.
		 */

		/**
		 * General settings.
		 */
		$this->start_controls_section(
			'general_style_section',
			[
				'label' => esc_html__( 'General', 'cheshalo' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'style',
			[
				'label'       => esc_html__( 'Style', 'cheshalo' ),
				'description' => esc_html__( 'You can use some of our predefined styles for your banner content.', 'cheshalo' ),
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'default'            => esc_html__( 'Default', 'cheshalo' ),
					'mask'               => esc_html__( 'Color mask', 'cheshalo' ),
					'shadow'             => esc_html__( 'Mask with shadow', 'cheshalo' ),
					'border'             => esc_html__( 'Bordered', 'cheshalo' ),
					'background'         => esc_html__( 'Bordered background', 'cheshalo' ),
					'content-background' => esc_html__( 'Content background', 'cheshalo' ),
				],
				'default'     => 'default',
			]
		);

		$this->add_control(
			'hover',
			[
				'label'       => esc_html__( 'Hover effect', 'cheshalo' ),
				'description' => esc_html__( 'Set beautiful hover effects for your banner.', 'cheshalo' ),
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'zoom'         => esc_html__( 'Zoom image', 'cheshalo' ),
					'parallax'     => esc_html__( 'Parallax', 'cheshalo' ),
					'background'   => esc_html__( 'Background', 'cheshalo' ),
					'border'       => esc_html__( 'Bordered', 'cheshalo' ),
					'zoom-reverse' => esc_html__( 'Zoom reverse', 'cheshalo' ),
					'none'         => esc_html__( 'Disable', 'cheshalo' ),
				],
				'default'     => 'none',
			]
		);

		$this->add_control(
			'cheshalo_color_scheme',
			[
				'label'   => esc_html__( 'Color Scheme', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					''      => esc_html__( 'Inherit', 'cheshalo' ),
					'light' => esc_html__( 'Light', 'cheshalo' ),
					'dark'  => esc_html__( 'Dark', 'cheshalo' ),
				],
				'default' => '',
			]
		);

		$this->add_control(
			'title_size',
			[
				'label'   => esc_html__( 'Predefined size', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default'     => esc_html__( 'Default (22px)', 'cheshalo' ),
					'small'       => esc_html__( 'Small (16px)', 'cheshalo' ),
					'large'       => esc_html__( 'Large (26px)', 'cheshalo' ),
					'extra-large' => esc_html__( 'Extra Large (36px)', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'custom_content_bg_color',
			[
				'label'     => esc_html__( 'Content background color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wrapper-content-banner' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'style' => 'content-background',
				],
			]
		);

		$this->end_controls_section();

		/**
		 * Title settings.
		 */
		$this->start_controls_section(
			'title_style_section',
			[
				'label' => esc_html__( 'Title', 'cheshalo' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'   => esc_html__( 'Tag', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'h1'   => esc_html__( 'h1', 'cheshalo' ),
					'h2'   => esc_html__( 'h2', 'cheshalo' ),
					'h3'   => esc_html__( 'h3', 'cheshalo' ),
					'h4'   => esc_html__( 'h4', 'cheshalo' ),
					'h5'   => esc_html__( 'h5', 'cheshalo' ),
					'h6'   => esc_html__( 'h6', 'cheshalo' ),
					'p'    => esc_html__( 'p', 'cheshalo' ),
					'div'  => esc_html__( 'div', 'cheshalo' ),
					'span' => esc_html__( 'span', 'cheshalo' ),
				],
				'default' => 'h4',
			]
		);

		$this->add_control(
			'title_decoration_style',
			[
				'label'   => esc_html__( 'Text decoration style', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default'  => esc_html__( 'Default', 'cheshalo' ),
					'colored'  => esc_html__( 'Colored', 'cheshalo' ),
					'bordered' => esc_html__( 'Bordered', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'custom_title_color',
			[
				'label'     => esc_html__( 'Color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner-title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => esc_html__( 'Custom typography', 'cheshalo' ),
				'selector' => '{{WRAPPER}} .banner-title',
			]
		);

		$this->end_controls_section();

		/**
		 * Subtitle settings.
		 */
		$this->start_controls_section(
			'subtitle_style_section',
			[
				'label' => esc_html__( 'Subtitle', 'cheshalo' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_style',
			[
				'label'   => esc_html__( 'Subtitle style', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default'    => esc_html__( 'Default', 'cheshalo' ),
					'background' => esc_html__( 'Background', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label'   => esc_html__( 'Predefined color', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Default', 'cheshalo' ),
					'primary' => esc_html__( 'Primary', 'cheshalo' ),
					'alt'     => esc_html__( 'Alternative', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'custom_subtitle_color',
			[
				'label'     => esc_html__( 'Color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner-subtitle' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'custom_subtitle_bg_color',
			[
				'label'     => esc_html__( 'Background color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner-subtitle' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'subtitle_style' => [ 'background' ],
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'subtitle_typography',
				'label'    => esc_html__( 'Custom typography', 'cheshalo' ),
				'selector' => '{{WRAPPER}} .banner-subtitle',
			]
		);

		$this->end_controls_section();

		/**
		 * Content settings.
		 */
		$this->start_controls_section(
			'content_style_section',
			[
				'label' => esc_html__( 'Content', 'cheshalo' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'content_text_size',
			[
				'label'   => esc_html__( 'Predefined size', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Default (14px)', 'cheshalo' ),
					'medium'  => esc_html__( 'Medium (16px)', 'cheshalo' ),
					'large'   => esc_html__( 'Large (18px)', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'custom_text_color',
			[
				'label'     => esc_html__( 'Color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner-inner' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'text_typography',
				'label'    => esc_html__( 'Custom typography', 'cheshalo' ),
				'selector' => '{{WRAPPER}} .banner-inner',
			]
		);

		$this->end_controls_section();

		/**
		 * Button settings.
		 */
		$this->start_controls_section(
			'button_style_section',
			[
				'label' => esc_html__( 'Button', 'cheshalo' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'btn_position',
			[
				'label'     => esc_html__( 'Button position', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'hover'  => esc_html__( 'Show on hover', 'cheshalo' ),
					'static' => esc_html__( 'Static', 'cheshalo' ),
				],
				'default'   => 'hover',
				'condition' => [
					'style!' => 'content-background',
				],
			]
		);

		$this->add_control(
			'btn_size',
			[
				'label'   => esc_html__( 'Predefined size', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default'     => esc_html__( 'Default', 'cheshalo' ),
					'extra-small' => esc_html__( 'Extra Small', 'cheshalo' ),
					'small'       => esc_html__( 'Small', 'cheshalo' ),
					'large'       => esc_html__( 'Large', 'cheshalo' ),
					'extra-large' => esc_html__( 'Extra Large', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'btn_color',
			[
				'label'   => esc_html__( 'Predefined color', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Default', 'cheshalo' ),
					'primary' => esc_html__( 'Primary', 'cheshalo' ),
					'alt'     => esc_html__( 'Alternative', 'cheshalo' ),
					'black'   => esc_html__( 'Black', 'cheshalo' ),
					'white'   => esc_html__( 'White', 'cheshalo' ),
					'custom'  => esc_html__( 'Custom', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$this->start_controls_tabs(
			'button_tabs_style',
			[
				'condition' => [
					'color' => [ 'custom' ],
				],
			]
		);

		$this->start_controls_tab(
			'button_tab_normal',
			[
				'label' => esc_html__( 'Normal', 'xtс   s-theme' ),
			]
		);

		$this->add_control(
			'bg_color',
			[
				'label'     => esc_html__( 'Background color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wd-button-wrapper a' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_scheme',
			[
				'label'   => esc_html__( 'Text color scheme', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'inherit' => esc_html__( 'Inherit', 'cheshalo' ),
					'dark'    => esc_html__( 'Dark', 'cheshalo' ),
					'light'   => esc_html__( 'Light', 'cheshalo' ),
				],
				'default' => 'inherit',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'button_tab_hover',
			[
				'label' => esc_html__( 'Hover', 'cheshalo' ),
			]
		);

		$this->add_control(
			'bg_color_hover',
			[
				'label'     => esc_html__( 'Background color hover', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wd-button-wrapper:hover a' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_scheme_hover',
			[
				'label'   => esc_html__( 'Text color scheme on hover', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'inherit' => esc_html__( 'Inherit', 'cheshalo' ),
					'dark'    => esc_html__( 'Dark', 'cheshalo' ),
					'light'   => esc_html__( 'Light', 'cheshalo' ),
				],
				'default' => 'inherit',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'btn_style',
			[
				'label'   => esc_html__( 'Style', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default'  => esc_html__( 'Default', 'cheshalo' ),
					'bordered' => esc_html__( 'Bordered', 'cheshalo' ),
					'link'     => esc_html__( 'Link button', 'cheshalo' ),
					'3d'       => esc_html__( '3D', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'btn_shape',
			[
				'label'     => esc_html__( 'Shape', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'rectangle'  => esc_html__( 'Rectangle', 'cheshalo' ),
					'round'      => esc_html__( 'Circle', 'cheshalo' ),
					'semi-round' => esc_html__( 'Round', 'cheshalo' ),
				],
				'condition' => [
					'btn_style!' => [ 'link' ],
				],
				'default'   => 'rectangle',
			]
		);

		$this->add_control(
			'button_icon_heading',
			[
				'label'     => esc_html__( 'Icon', 'cheshalo' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		cheshalo_get_button_style_icon_map( $this );

		$this->add_control(
			'button_layout_heading',
			[
				'label'     => esc_html__( 'Layout', 'cheshalo' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'full_width',
			[
				'label'        => esc_html__( 'Full width', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->add_control(
			'button_hr',
			[
				'type'  => Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);

		$this->add_control(
			'hide_btn_tablet',
			[
				'label'        => esc_html__( 'Hide button on tablet', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->add_control(
			'hide_btn_mobile',
			[
				'label'        => esc_html__( 'Hide button on mobile', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->end_controls_section();

		/**
		 * Layout settings.
		 */
		$this->start_controls_section(
			'layout_style_section',
			[
				'label' => esc_html__( 'Layout', 'cheshalo' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'horizontal_alignment',
			[
				'label'   => esc_html__( 'Content horizontal alignment', 'cheshalo' ),
				'type'    => 'wd_buttons',
				'options' => [
					'left'   => [
						'title' => esc_html__( 'Left', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/horizontal/left.png',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/horizontal/center.png',
					],
					'right'  => [
						'title' => esc_html__( 'Right', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/horizontal/right.png',
					],

				],
				'default' => 'left',
			]
		);

		$this->add_control(
			'vertical_alignment',
			[
				'label'   => esc_html__( 'Content vertical alignment', 'cheshalo' ),
				'type'    => 'wd_buttons',
				'options' => [
					'top'    => [
						'title' => esc_html__( 'Top', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/vertical/top.png',
					],
					'middle' => [
						'title' => esc_html__( 'Middle', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/vertical/middle.png',
					],
					'bottom' => [
						'title' => esc_html__( 'Bottom', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/vertical/bottom.png',
					],
				],
				'default' => 'top',
			]
		);

		$this->add_control(
			'text_alignment',
			[
				'label'   => esc_html__( 'Text alignment', 'cheshalo' ),
				'type'    => 'wd_buttons',
				'options' => [
					'left'   => [
						'title' => esc_html__( 'Left', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
					],
					'right'  => [
						'title' => esc_html__( 'Right', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					],
				],
				'default' => 'left',
			]
		);

		$this->add_responsive_control(
			'width',
			[
				'label'          => esc_html__( 'Width', 'cheshalo' ),
				'type'           => Controls_Manager::SLIDER,
				'default'        => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units'     => [ '%' ],
				'range'          => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors'      => [
					'{{WRAPPER}} .promo-banner:not(.banner-content-background) .content-banner, {{WRAPPER}} .promo-banner.banner-content-background .wrapper-content-banner' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'increase_spaces',
			[
				'label'        => esc_html__( 'Increase spaces', 'cheshalo' ),
				'description'  => esc_html__( 'Suggest to use this option if you have large banners. Padding will be set in percentage to your screen width.', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		cheshalo_elementor_banner_template( $this->get_settings_for_display() );
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Banner() );
