<?php
/**
 * Global map file.
 *
 * @package xts
 */

use Elementor\Controls_Manager;

if ( ! function_exists( 'cheshalo_get_animation_map' ) ) {
	/**
	 * Get animation map
	 *
	 * @since 1.0.0
	 *
	 * @param object $element Element object.
	 */
	function cheshalo_get_animation_map( $element ) {
		$element->add_control(
			'wd_animation',
			[
				'label'        => esc_html__( 'Animations', 'cheshalo' ),
				'description'  => esc_html__( 'Add an appearance animation effect to this element.', 'cheshalo' ),
				'type'         => Controls_Manager::SELECT2,
				'label_block'  => true,
				'options'      => [
					''                  => esc_html__( 'None', 'cheshalo' ),
					'slide-from-top'    => esc_html__( 'Slide from top', 'cheshalo' ),
					'slide-from-bottom' => esc_html__( 'Slide from bottom', 'cheshalo' ),
					'slide-from-left'   => esc_html__( 'Slide from left', 'cheshalo' ),
					'slide-from-right'  => esc_html__( 'Slide from right', 'cheshalo' ),
					'bottom-flip-x'     => esc_html__( 'Flip X bottom', 'cheshalo' ),
					'top-flip-x'        => esc_html__( 'Flip X top', 'cheshalo' ),
					'left-flip-y'       => esc_html__( 'Flip Y left', 'cheshalo' ),
					'right-flip-y'      => esc_html__( 'Flip Y right', 'cheshalo' ),
					'zoom-in'           => esc_html__( 'Zoom in', 'cheshalo' ),
				],
				'default'      => '',
				'render_type'  => 'template',
				'prefix_class' => 'wd-animation-',
			]
		);

		$element->add_control(
			'wd_animation_duration',
			[
				'label'        => esc_html__( 'Animation duration', 'cheshalo' ),
				'type'         => Controls_Manager::SELECT,
				'default'      => 'normal',
				'options'      => [
					'slow'   => esc_html__( 'Slow', 'cheshalo' ),
					'normal' => esc_html__( 'Normal', 'cheshalo' ),
					'fast'   => esc_html__( 'Fast', 'cheshalo' ),
				],
				'condition'    => [
					'wd_animation!' => '',
				],
				'render_type'  => 'template',
				'prefix_class' => 'wd-animation-',
			]
		);

		$element->add_control(
			'wd_animation_delay',
			[
				'label'        => esc_html__( 'Animation delay', 'cheshalo' ) . ' (ms)',
				'type'         => Controls_Manager::NUMBER,
				'default'      => 100,
				'min'          => 0,
				'step'         => 100,
				'condition'    => [
					'wd_animation!' => '',
				],
				'render_type'  => 'template',
				'prefix_class' => 'wd_delay_',
			]
		);
	}
}
