<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
*  Button element map
* ------------------------------------------------------------------------------------------------
*/

if( ! function_exists( 'cheshalo_vc_shortcode_button' ) ) {
	function cheshalo_vc_shortcode_button() {
		if ( ! shortcode_exists( 'cheshalo_button' ) ) {
			return;
		}
		
		vc_map( cheshalo_get_cheshalo_button_shortcode_args() );
	}
	add_action( 'vc_before_init', 'cheshalo_vc_shortcode_button' );
}

if( ! function_exists( 'cheshalo_get_cheshalo_button_shortcode_args' ) ) {
	function cheshalo_get_cheshalo_button_shortcode_args() {
		return array(
			'name' => esc_html__( 'Button', 'cheshalo' ),
			'base' => 'cheshalo_button',
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'Simple button in different theme styles', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/button.svg',
			'params' => cheshalo_get_button_shortcode_params()
		);
	}
}

if( ! function_exists( 'cheshalo_get_button_shortcode_params' ) ) {
	function cheshalo_get_button_shortcode_params() {
		return apply_filters( 'cheshalo_get_button_shortcode_params', array(
				array(
					'type' => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id'
				),
				/**
				* Button
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Button', 'cheshalo' ),
					'param_name' => 'button_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'vc_link',
					'heading' => esc_html__( 'Link', 'cheshalo' ),
					'param_name' => 'link',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_dropdown',
					'heading' => esc_html__( 'Predefined button color', 'cheshalo' ),
					'param_name' => 'color',
					'value' => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Primary color', 'cheshalo' ) => 'primary',
						esc_html__( 'Alternative color', 'cheshalo' ) => 'alt',
						esc_html__( 'White', 'cheshalo' ) => 'white',
						esc_html__( 'Black', 'cheshalo' ) => 'black',
					),
					'style' => array(
						'default' => '#f3f3f3',
						'primary' => cheshalo_get_color_value( 'primary-color', '#7eb934' ),
						'alt' => cheshalo_get_color_value( 'secondary-color', '#fbbc34' ),
						'black' => '#212121',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Button size', 'cheshalo' ),
					'param_name' => 'size',
					'value' => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Extra Small', 'cheshalo' ) => 'extra-small',
						esc_html__( 'Small', 'cheshalo' ) => 'small',
						esc_html__( 'Large', 'cheshalo' ) => 'large',
						esc_html__( 'Extra Large', 'cheshalo' ) => 'extra-large',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Button style', 'cheshalo' ),
					'param_name' => 'style',
				    'value' => array( 
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Bordered', 'cheshalo' ) => 'bordered',
						esc_html__( 'Link button', 'cheshalo' ) => 'link',
						esc_html__( '3D', 'cheshalo' ) => '3d',
					),
					'images_value' => array(
						'default' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/default.png',
						'bordered' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/bordered.png',
						'link' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/link.png',
						'3d' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/3d.png',
					),
					'title' => false,
					'std' => 'default',
					'edit_field_class' => 'vc_col-xs-12 vc_column button-style',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Button shape', 'cheshalo' ),
					'param_name' => 'shape',
				    'value' => array( 
						esc_html__( 'Rectangle', 'cheshalo' ) => 'rectangle',
						esc_html__( 'Circle', 'cheshalo' ) => 'round',
						esc_html__( 'Round', 'cheshalo' ) => 'semi-round',
					),
					'images_value' => array(
						'rectangle' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/rectangle.png',
						'round' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/circle.png',
						'semi-round' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/round.png',
					),
					'dependency' => array(
						'element' => 'style',
						'value_not_equal_to' => array( 'round', 'link' ),
					),
					'title' => false,
					'std' => 'rectangle',
					'edit_field_class' => 'vc_col-xs-12 vc_column button-shape',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Icon library', 'cheshalo' ),
					'value' => array(
						esc_html__( 'Font Awesome', 'cheshalo' ) => 'fontawesome',
						esc_html__( 'Open Iconic', 'cheshalo' ) => 'openiconic',
						esc_html__( 'Typicons', 'cheshalo' ) => 'typicons',
						esc_html__( 'Entypo', 'cheshalo' ) => 'entypo',
						esc_html__( 'Linecons', 'cheshalo' ) => 'linecons',
						esc_html__( 'Mono Social', 'cheshalo' ) => 'monosocial',
						esc_html__( 'Material', 'cheshalo' ) => 'material'
					),
					'param_name' => 'icon_library',
					'hint' => esc_html__( 'Select icon library.', 'cheshalo' ),
					'dependency' => array(
						'element' => 'list_type',
						'value' => 'icon'
					)
				),
				array(
					'type' => 'iconpicker',
					'heading' => esc_html__( 'Icon', 'cheshalo' ),
					'param_name' => 'icon_fontawesome',
					'value' => '',
					'settings' => array(
						'emptyIcon' => true,
						'iconsPerPage' => 4000
					),
					'dependency' => array(
						'element' => 'icon_library',
						'value' => array('fontawesome')
					),
					'hint' => esc_html__( 'Select icon from library.', 'cheshalo' ),
				),
				array(
					'type' => 'iconpicker',
					'heading' => esc_html__( 'Icon', 'cheshalo' ),
					'param_name' => 'icon_openiconic',
					'settings' => array(
						'emptyIcon' => true,
						'type' => 'openiconic',
						'iconsPerPage' => 4000
					),
					'dependency' => array(
						'element' => 'icon_library',
						'value' => array('openiconic')
					),
					'hint' => esc_html__( 'Select icon from library.', 'cheshalo' ),
				),
				array(
					'type' => 'iconpicker',
					'heading' => esc_html__( 'Icon', 'cheshalo' ),
					'param_name' => 'icon_typicons',
					'settings' => array(
						'emptyIcon' => true,
						'type' => 'typicons',
						'iconsPerPage' => 4000
					),
					'dependency' => array(
						'element' => 'icon_library',
						'value' => array('typicons')
					),
					'hint' => esc_html__( 'Select icon from library.', 'cheshalo' )
				),
				array(
					'type' => 'iconpicker',
					'heading' => esc_html__( 'Icon', 'cheshalo' ),
					'param_name' => 'icon_entypo',
					'settings' => array(
						'emptyIcon' => true,
						'type' => 'entypo',
						'iconsPerPage' => 4000
					),
					'dependency' => array(
						'element' => 'icon_library',
						'value' => array('entypo')
					)
				),
				array(
					'type' => 'iconpicker',
					'heading' => esc_html__( 'Icon', 'cheshalo' ),
					'param_name' => 'icon_linecons',
					'settings' => array(
						'emptyIcon' => true,
						'type' => 'linecons',
						'iconsPerPage' => 4000
					),
					'dependency' => array(
						'element' => 'icon_library',
						'value' => array('linecons')
					),
					'hint' => esc_html__( 'Select icon from library.', 'cheshalo' )
				),
				array(
					'type' => 'iconpicker',
					'heading' => esc_html__( 'Icon', 'cheshalo' ),
					'param_name' => 'icon_monosocial',
					'settings' => array(
						'emptyIcon' => true,
						'type' => 'monosocial',
						'iconsPerPage' => 4000
					),
					'dependency' => array(
						'element' => 'icon_library',
						'value' => array('monosocial')
					),
					'hint' => esc_html__( 'Select icon from library.', 'cheshalo' )
				),
				array(
					'type' => 'iconpicker',
					'heading' => esc_html__( 'Icon', 'cheshalo' ),
					'param_name' => 'icon_material',
					'settings' => array(
						'emptyIcon' => true,
						'type' => 'material',
						'iconsPerPage' => 4000
					),
					'dependency' => array(
						'element' => 'icon_library',
						'value' => array('material')
					),
					'hint' => esc_html__( 'Select icon from library.', 'cheshalo' )
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Button icon position', 'cheshalo' ),
					'param_name' => 'icon_position',
					'value' => array(
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'std' => 'right',
					'edit_field_class' => 'vc_col-xs-12 vc_column button-style',
				),
				/**
				* Layout
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout_divider',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Full width', 'cheshalo' ),
					'param_name' => 'full_width',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Button inline', 'cheshalo' ),
					'param_name' => 'button_inline',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Align', 'cheshalo' ),
					'param_name' => 'align',
				    'value' => array( 
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images_value' => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left' => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right' => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'dependency' => array(
						'element' => 'button_inline',
						'value_not_equal_to' => array( 'yes' ),
					),
					'std' => 'center',
					'wood_tooltip' => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				/**
				* Idle state
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Idle state', 'cheshalo' ),
					'group' => esc_html__( 'Custom color', 'cheshalo' ),
					'param_name' => 'idle_divider',
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Background color', 'cheshalo' ),
					'param_name' => 'bg_color',
					'css_args' => array(
						'background-color' => array(
							' a',
						),
						'border-color' => array(
							' a',
						),
					),
					'group' => esc_html__( 'Custom color', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column', 
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Text color scheme', 'cheshalo' ),
					'param_name' => 'color_scheme',
					'group' => esc_html__( 'Custom color', 'cheshalo' ),
					'value' => array(
						esc_html__( 'Light', 'cheshalo' ) => 'light',
						esc_html__( 'Dark', 'cheshalo' ) => 'dark',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column', 
				),
				/**
				* Hover state
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Hover state', 'cheshalo' ),
					'group' => esc_html__( 'Custom color', 'cheshalo' ),
					'param_name' => 'hover_divider',
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Background color on hover', 'cheshalo' ),
					'param_name' => 'bg_color_hover',
					'css_args' => array(
						'background-color' => array(
							' a:hover',
						),
						'border-color' => array(
							' a:hover',
						),
					),
					'group' => esc_html__( 'Custom color', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column', 
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Text color scheme on hover', 'cheshalo' ),
					'param_name' => 'color_scheme_hover',
					'group' => esc_html__( 'Custom color', 'cheshalo' ),
					'value' => array(
						esc_html__( 'Light', 'cheshalo' ) => 'light',
						esc_html__( 'Dark', 'cheshalo' ) => 'dark',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column', 
				),
				/**
				 * Smooth scroll
				 */
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Smooth scroll', 'cheshalo' ),
					'param_name' => 'smooth_divider',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Smooth scroll', 'cheshalo' ),
					'hint' => esc_html__( 'When you turn on this option you need to specify this button link with a hash symbol. For example #section-id Then you need to have a section with an ID of "section-id" and this button click will smoothly scroll the page to that section.', 'cheshalo' ),
					'param_name' => 'button_smooth_scroll',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Smooth scroll time (ms)', 'cheshalo' ),
					'param_name' => 'button_smooth_scroll_time',
					'dependency' => array(
						'element' => 'button_smooth_scroll',
						'value_not_equal_to' => array( 'no' ),
					),
					'std' => '100',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Smooth scroll offset (px)', 'cheshalo' ),
					'param_name' => 'button_smooth_scroll_offset',
					'dependency' => array(
						'element' => 'button_smooth_scroll',
						'value_not_equal_to' => array( 'no' ),
					),
					'std' => '100',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Extra
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				( function_exists( 'vc_map_add_css_animation' ) ) ? vc_map_add_css_animation( true ) : '',
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				),
				/**
				 * Advanced.
				 */
				function_exists( 'cheshalo_get_vc_animation_map' ) ? cheshalo_get_vc_animation_map() : '',
				function_exists( 'cheshalo_get_vc_animation_delay_map' ) ? cheshalo_get_vc_animation_delay_map() : '',
				function_exists( 'cheshalo_get_vc_animation_duration_map' ) ? cheshalo_get_vc_animation_duration_map() : '',
			)
		);
	}
}
