<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );}
/**
* ------------------------------------------------------------------------------------------------
* Extra menu list element map
* ------------------------------------------------------------------------------------------------
*/

if ( ! function_exists( 'cheshalo_vc_map_extra_menu' ) ) {
	function cheshalo_vc_map_extra_menu() {
		if ( ! shortcode_exists( 'extra_menu' ) ) {
			return;
		}

		vc_map(
			array(
				'name'                    => esc_html__( 'Extra menu list', 'cheshalo' ),
				'base'                    => 'extra_menu',
				'as_parent'               => array( 'only' => 'extra_menu_list' ),
				'content_element'         => true,
				'show_settings_on_create' => true,
				'category'                => esc_html__( 'Theme elements', 'cheshalo' ),
				'description'             => esc_html__( 'Create a menu list for your mega menu dropdown', 'cheshalo' ),
				'icon'                    => CHESHALO_ASSETS . '/images/vc-icon/extra-menu-list.svg',
				'params'                  => array(
					/**
					* Link
					*/
					array(
						'type'       => 'cheshalo_title_divider',
						'holder'     => 'div',
						'title'      => esc_html__( 'Link', 'cheshalo' ),
						'param_name' => 'link_divider',
					),
					array(
						'type'             => 'textfield',
						'holder'           => 'div',
						'heading'          => esc_html__( 'Title', 'cheshalo' ),
						'param_name'       => 'title',
						'edit_field_class' => 'vc_col-sm-6 vc_column',

					),
					array(
						'type'             => 'vc_link',
						'heading'          => esc_html__( 'Link', 'cheshalo' ),
						'param_name'       => 'link',
						'hint'             => esc_html__( 'Enter URL if you want this parent menu item to have a link.', 'cheshalo' ),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
					),
					/**
					* Label
					*/
					array(
						'type'       => 'cheshalo_title_divider',
						'holder'     => 'div',
						'title'      => esc_html__( 'Label', 'cheshalo' ),
						'param_name' => 'label_divider',
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Label text (optional)', 'cheshalo' ),
						'param_name'       => 'label_text',
						'hint'             => esc_html__( 'Write a label for this menu item badge like “Sale”, “Hot”, “New” etc. Leave empty to not add any badges.', 'cheshalo' ),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
					),
					array(
						'type'             => 'cheshalo_dropdown',
						'heading'          => esc_html__( 'Label color', 'cheshalo' ),
						'param_name'       => 'label',
						'value'            => array(
							esc_html__( 'Primary Color', 'cheshalo' ) => 'primary',
							esc_html__( 'Secondary', 'cheshalo' ) => 'secondary',
							esc_html__( 'Red', 'cheshalo' ) => 'red',
							esc_html__( 'Green', 'cheshalo' ) => 'green',
							esc_html__( 'Blue', 'cheshalo' ) => 'blue',
							esc_html__( 'Orange', 'cheshalo' ) => 'orange',
							esc_html__( 'Grey', 'cheshalo' ) => 'grey',
							esc_html__( 'White', 'cheshalo' ) => 'white',
							esc_html__( 'Black', 'cheshalo' ) => 'black',
						),
						'style'            => array(
							'primary'   => cheshalo_get_color_value( 'primary-color', '#7eb934' ),
							'secondary' => cheshalo_get_color_value( 'secondary-color', '#fbbc34' ),
							'red'       => '#D41212',
							'green'     => '#65B32E',
							'blue'      => '#00A1BE',
							'orange'    => '#fbbc34',
							'grey'      => '#ECECEC',
							'black'     => '#000000',
						),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
					),
					/**
					 * Image
					 */
					array(
						'type'       => 'cheshalo_title_divider',
						'holder'     => 'div',
						'title'      => esc_html__( 'Image', 'cheshalo' ),
						'param_name' => 'image_divider',
					),
					array(
						'type'             => 'attach_image',
						'heading'          => esc_html__( 'Image', 'cheshalo' ),
						'param_name'       => 'image',
						'value'            => '',
						'hint'             => esc_html__( 'Select image from media library.', 'cheshalo' ),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Image size', 'cheshalo' ),
						'param_name'       => 'image_size',
						'hint'             => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
						'description'      => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
					),
					/**
					* Extra
					*/
					array(
						'type'       => 'cheshalo_title_divider',
						'holder'     => 'div',
						'title'      => esc_html__( 'Extra options', 'cheshalo' ),
						'param_name' => 'extra_divider',
					),
					( function_exists( 'vc_map_add_css_animation' ) ) ? vc_map_add_css_animation( true ) : '',
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
						'param_name' => 'el_class',
						'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
					),
				),
				'js_view'                 => 'VcColumnView',
			)
		);

		vc_map(
			array(
				'name'            => esc_html__( 'Extra menu list item', 'cheshalo' ),
				'base'            => 'extra_menu_list',
				'as_child'        => array( 'only' => 'extra_menu' ),
				'content_element' => true,
				'category'        => esc_html__( 'Theme elements', 'cheshalo' ),
				'description'     => esc_html__( 'A link for your extra menu list', 'cheshalo' ),
				'icon'            => CHESHALO_ASSETS . '/images/vc-icon/extra-menu-list-item.svg',
				'params'          => array(
					/**
					* Link
					*/
					array(
						'type'       => 'cheshalo_title_divider',
						'holder'     => 'div',
						'title'      => esc_html__( 'Link', 'cheshalo' ),
						'param_name' => 'link_divider',
					),
					array(
						'type'             => 'textfield',
						'holder'           => 'div',
						'heading'          => esc_html__( 'Title', 'cheshalo' ),
						'param_name'       => 'title',
						'edit_field_class' => 'vc_col-sm-6 vc_column',

					),
					array(
						'type'             => 'vc_link',
						'heading'          => esc_html__( 'Link', 'cheshalo' ),
						'param_name'       => 'link',
						'hint'             => esc_html__( 'Enter URL if you want this parent menu item to have a link.', 'cheshalo' ),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
					),
					/**
					* Label
					*/
					array(
						'type'       => 'cheshalo_title_divider',
						'holder'     => 'div',
						'title'      => esc_html__( 'Label', 'cheshalo' ),
						'param_name' => 'label_divider',
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Label text (optional)', 'cheshalo' ),
						'param_name'       => 'label_text',
						'hint'             => esc_html__( 'Write a label for this menu item badge like “Sale”, “Hot”, “New” etc. Leave empty to not add any badges.', 'cheshalo' ),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
					),
					array(
						'type'             => 'cheshalo_dropdown',
						'heading'          => esc_html__( 'Label color', 'cheshalo' ),
						'param_name'       => 'label',
						'value'            => array(
							esc_html__( 'Primary Color', 'cheshalo' ) => 'primary',
							esc_html__( 'Secondary', 'cheshalo' ) => 'secondary',
							esc_html__( 'Red', 'cheshalo' ) => 'red',
							esc_html__( 'Green', 'cheshalo' ) => 'green',
							esc_html__( 'Blue', 'cheshalo' ) => 'blue',
							esc_html__( 'Orange', 'cheshalo' ) => 'orange',
							esc_html__( 'Grey', 'cheshalo' ) => 'grey',
							esc_html__( 'White', 'cheshalo' ) => 'white',
							esc_html__( 'Black', 'cheshalo' ) => 'black',
						),
						'style'            => array(
							'primary'   => cheshalo_get_color_value( 'primary-color', '#7eb934' ),
							'secondary' => cheshalo_get_color_value( 'secondary-color', '#fbbc34' ),
							'red'       => '#D41212',
							'green'     => '#65B32E',
							'blue'      => '#00A1BE',
							'orange'    => '#fbbc34',
							'grey'      => '#ECECEC',
							'black'     => '#000000',
						),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
					),
					/**
					 * Image
					 */
					array(
						'type'       => 'cheshalo_title_divider',
						'holder'     => 'div',
						'title'      => esc_html__( 'Image', 'cheshalo' ),
						'param_name' => 'image_divider',
					),
					array(
						'type'             => 'attach_image',
						'heading'          => esc_html__( 'Image', 'cheshalo' ),
						'param_name'       => 'image',
						'value'            => '',
						'hint'             => esc_html__( 'Select image from media library.', 'cheshalo' ),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Image size', 'cheshalo' ),
						'param_name'       => 'image_size',
						'hint'             => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
						'edit_field_class' => 'vc_col-sm-6 vc_column',
						'description'      => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
					),
					/**
					* Extra
					*/
					array(
						'type'       => 'cheshalo_title_divider',
						'holder'     => 'div',
						'title'      => esc_html__( 'Extra options', 'cheshalo' ),
						'param_name' => 'extra_divider',
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
						'param_name' => 'el_class',
						'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
					),
				),
			)
		);
	}
	add_action( 'vc_before_init', 'cheshalo_vc_map_extra_menu' );
}

if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
	class WPBakeryShortCode_extra_menu extends WPBakeryShortCodesContainer {

	}
}

// Replace Wbc_Inner_Item with your base name from mapping for nested element
if ( class_exists( 'WPBakeryShortCode' ) ) {
	class WPBakeryShortCode_extra_menu_list extends WPBakeryShortCode {

	}
}
