<?php
if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
}
/**
* ------------------------------------------------------------------------------------------------
* Instagram element map
* ------------------------------------------------------------------------------------------------
*/

if ( ! function_exists( 'cheshalo_vc_map_instagram' ) ) {
	function cheshalo_vc_map_instagram() {
		if ( ! shortcode_exists( 'cheshalo_instagram' ) ) {
			return;
		}

		vc_map(
			array(
				'name'        => esc_html__( 'Instagram', 'cheshalo' ),
				'base'        => 'cheshalo_instagram',
				'category'    => esc_html__( 'Theme elements', 'cheshalo' ),
				'description' => esc_html__( 'Instagram photos', 'cheshalo' ),
				'icon'        => CHESHALO_ASSETS . '/images/vc-icon/instagram.svg',
				'params'      => cheshalo_get_instagram_params(),
			)
		);
	}
	add_action( 'vc_before_init', 'cheshalo_vc_map_instagram' );
}

if ( ! function_exists( 'cheshalo_get_instagram_params' ) ) {
	function cheshalo_get_instagram_params() {
		return apply_filters(
			'cheshalo_get_instagram_params',
			array(
				/**
				 * Data
				 */
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Data', 'cheshalo' ),
					'param_name' => 'data_divider',
				),
				array(
					'type'       => 'cheshalo_button_set',
					'heading'    => esc_html__( 'Source type', 'cheshalo' ),
					'param_name' => 'data_source',
					'value'      => array(
						esc_html__( 'Scrape (deprecated)', 'cheshalo' ) => 'scrape',
						esc_html__( 'AJAX (deprecated)', 'cheshalo' ) => 'ajax',
						esc_html__( 'API', 'cheshalo' )    => 'api',
						esc_html__( 'Images', 'cheshalo' ) => 'images',
					),
					'hint'       => 'API request type<br>
Scrape - parse Instagram page and take photos by username. Now deprecated and may be blocked by Instagram.<br>
AJAX - send AJAX request to the Instagram page on frontend. Works more stable then simple scrape.<br>
API - the best safe and legal option to obtain Instagram photos. Requires Instagram APP configuration. <br>
Follow our documentation <a href="https://themefars.com/docs/cheshalo/faq-guides/setup-instagram-api/" target="_blank">here</a>',
				),
				/**
				 * Images
				 */
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Images', 'cheshalo' ),
					'param_name' => 'images_divider',
					'dependency' => array(
						'element' => 'data_source',
						'value'   => array( 'images' ),
					),
				),
				array(
					'type'             => 'attach_images',
					'heading'          => esc_html__( 'Images', 'cheshalo' ),
					'param_name'       => 'images',
					'value'            => '',
					'hint'             => esc_html__( 'Select images from media library.', 'cheshalo' ),
					'dependency'       => array(
						'element' => 'data_source',
						'value'   => array( 'images' ),
					),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Image size', 'cheshalo' ),
					'param_name'       => 'images_size',
					'hint'             => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\'. Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'dependency'       => array(
						'element' => 'data_source',
						'value'   => array( 'images' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'description'      => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Images link', 'cheshalo' ),
					'param_name'       => 'images_link',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Likes limit', 'cheshalo' ),
					'param_name'       => 'images_likes',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'default'          => '1000-10000',
					'description'      => 'Example: 1000-10000',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Comments limit', 'cheshalo' ),
					'param_name'       => 'images_comments',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'default'          => '0-1000',
					'description'      => 'Example: 0-1000',
				),
				/**
				* Content
				*/
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Content', 'cheshalo' ),
					'param_name' => 'content_divider',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Title', 'cheshalo' ),
					'param_name'       => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Username', 'cheshalo' ),
					'hint'             => esc_html__( 'Enter your Instagram username. For example: asos', 'cheshalo' ),
					'param_name'       => 'username',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_slider',
					'heading'          => esc_html__( 'Number of photos', 'cheshalo' ),
					'param_name'       => 'number',
					'value'            => array(
						'9'  => '9',
						'12' => '12',
						'11' => '11',
						'10' => '10',
						'8'  => '8',
						'7'  => '7',
						'6'  => '6',
						'5'  => '5',
						'4'  => '4',
						'3'  => '3',
						'2'  => '2',
						'1'  => '1',
					),
					'min'              => '1',
					'max'              => '30',
					'step'             => '1',
					'default'          => '9',
					'units'            => '',
					'dependency'       => array(
						'element'            => 'data_source',
						'value_not_equal_to' => array( 'images' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_button_set',
					'heading'          => esc_html__( 'Photo size', 'cheshalo' ),
					'param_name'       => 'size',
					'value'            => array(
						esc_html__( 'Medium', 'cheshalo' ) => 'medium',
						esc_html__( 'Thumbnail', 'cheshalo' ) => 'thumbnail',
						esc_html__( 'Large', 'cheshalo' )  => 'large',
					),
					'dependency'       => array(
						'element'            => 'data_source',
						'value_not_equal_to' => array( 'images' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'       => 'textarea_html',
					'holder'     => 'div',
					'heading'    => esc_html__( 'Instagram text', 'cheshalo' ),
					'param_name' => 'content',
					'skip_in'    => 'widget',
					'hint'       => esc_html__( 'Add here few words about your instagram profile.', 'cheshalo' ),
				),
				/**
				* Link
				*/
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Link', 'cheshalo' ),
					'param_name' => 'link_divider',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Open link in', 'cheshalo' ),
					'param_name'       => 'target',
					'value'            => array(
						esc_html__( 'Current window (_self)', 'cheshalo' ) => '_self',
						esc_html__( 'New window (_blank)', 'cheshalo' ) => '_blank',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Link text', 'cheshalo' ),
					'param_name'       => 'link',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Layout
				*/
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout_divider',
				),
				array(
					'type'             => 'cheshalo_button_set',
					'heading'          => esc_html__( 'Layout', 'cheshalo' ),
					'param_name'       => 'design',
					'skip_in'          => 'widget',
					'value'            => array(
						esc_html__( 'Grid', 'cheshalo' )   => 'grid',
						esc_html__( 'Slider', 'cheshalo' ) => 'slider',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_slider',
					'heading'          => esc_html__( 'Photos per row', 'cheshalo' ),
					'param_name'       => 'per_row',
					'skip_in'          => 'widget',
					'min'              => '1',
					'max'              => '12',
					'step'             => '1',
					'default'          => '3',
					'units'            => '',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'hint'             => esc_html__( 'Number of photos per row for grid design or items in slider per view.', 'cheshalo' ),
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Add spaces between photos', 'cheshalo' ),
					'skip_in'          => 'widget',
					'param_name'       => 'spacing',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 0,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Space between images', 'cheshalo' ),
					'param_name'       => 'spacing_custom',
					'skip_in'          => 'widget',
					'value'            => array(
						'',
						0,
						2,
						6,
						10,
						20,
						30,
					),
					'dependency'       => array(
						'element' => 'spacing',
						'value'   => array( '1' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Rounded corners for images', 'cheshalo' ),
					'skip_in'          => 'widget',
					'param_name'       => 'rounded',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 0,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Hide likes and comments', 'cheshalo' ),
					'skip_in'          => 'widget',
					'param_name'       => 'hide_mask',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 0,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Hide pagination control', 'cheshalo' ),
					'param_name'       => 'hide_pagination_control',
					'hint'             => esc_html__( 'If "YES" pagination control will be removed', 'cheshalo' ),
					'true_state'       => 'yes',
					'false_state'      => 'no',
					'default'          => 'no',
					'skip_in'          => 'widget',
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'slider' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Hide prev/next buttons', 'cheshalo' ),
					'param_name'       => 'hide_prev_next_buttons',
					'hint'             => esc_html__( 'If "YES" prev/next control will be removed', 'cheshalo' ),
					'true_state'       => 'yes',
					'false_state'      => 'no',
					'default'          => 'no',
					'skip_in'          => 'widget',
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'slider' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Extra
				*/
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider',
				),
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
					'skip_in'    => 'widget',
					'param_name' => 'el_class',
					'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
				),
			)
		);
	}
}
