<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
* Portfolio element map
* ------------------------------------------------------------------------------------------------
*/

if( ! function_exists( 'cheshalo_vc_map_portfolio' ) ) {
	function cheshalo_vc_map_portfolio() {
		if ( ! shortcode_exists( 'cheshalo_portfolio' ) || ! cheshalo_get_opt( 'portfolio', '1' ) ) {
			return;
		}

		vc_map( array(
			'name' => esc_html__( 'Portfolio', 'cheshalo' ),
			'base' => 'cheshalo_portfolio',
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'Showcase your projects or gallery', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/portfolio.svg',
			'params' => array(
				/**
				* Layout
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout_divider'
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout',
					'value' => array(
						esc_html__( 'Grid', 'cheshalo' ) => 'grid',
						esc_html__( 'Carousel', 'cheshalo' ) => 'carousel',
					),
					'save_always' => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'default' => 'carousel',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Number of projects per page', 'cheshalo' ),
					'param_name' => 'posts_per_page',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_slider',
					'heading' => esc_html__( 'Columns', 'cheshalo' ),
					'param_name' => 'columns',
					'min' => '2',
					'max' => '6',
					'step' => '1',
					'default' => '3',
					'units' => '',
					'dependency'       => array(
						'element' => 'layout',
						'value' => 'grid',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Space between projects', 'cheshalo' ),
					'param_name' => 'spacing',
					'value' => array(
	                    0,2,6,10,20,30
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Show categories filters', 'cheshalo' ),
					'param_name' => 'filters',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 0,
					'dependency'       => array(
						'element' => 'layout',
						'value' => 'grid',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Filters type', 'cheshalo' ),
					'param_name' => 'filters_type',
					'value' => array(
						esc_html__( 'Links', 'cheshalo' ) => 'links',
						esc_html__( 'Masonry', 'cheshalo' ) => 'masonry',
					),
					'save_always' => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'default' => 'masonry',
					'dependency'       => array(
						'element' => 'filters',
						'value' => '1',
					),
				),
				/**
				 * Carousel
				 */
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Carousel', 'cheshalo' ),
					'param_name' => 'carousel_divider',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
				),
				array(
					'type' => 'cheshalo_slider',
					'heading' => esc_html__( 'Slides per view', 'cheshalo' ),
					'param_name' => 'slides_per_view',
					'min' => '1',
					'max' => '6',
					'step' => '1',
					'default' => '3',
					'units' => '',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'hint' => esc_html__( 'Set numbers of slides you want to display at the same time on slider\'s container for carousel mode.', 'cheshalo' ),
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Scroll per page', 'cheshalo' ),
					'param_name' => 'scroll_per_page',
					'hint' => esc_html__( 'Scroll per page not per item. This affect next/prev buttons and mouse/touch dragging.', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'yes',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Slider autoplay', 'cheshalo' ),
					'param_name' => 'autoplay',
					'hint' => esc_html__( 'Enables autoplay mode.', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Slider speed', 'cheshalo' ),
					'param_name' => 'speed',
					'value' => '5000',
					'hint' => esc_html__( 'Duration of animation between slides (in ms)', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Slider loop', 'cheshalo' ),
					'param_name' => 'wrap',
					'hint' => esc_html__( 'Enables loop mode.', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Hide pagination control', 'cheshalo' ),
					'param_name' => 'hide_pagination_control',
					'hint' => esc_html__( 'If "YES" pagination control will be removed', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Hide prev/next buttons', 'cheshalo' ),
					'param_name' => 'hide_prev_next_buttons',
					'hint' => esc_html__( 'If "YES" prev/next control will be removed', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Init carousel on scroll', 'cheshalo' ),
					'hint' => esc_html__( 'This option allows you to init carousel script only when visitor scroll the page to the slider. Useful for performance optimization.', 'cheshalo' ),
					'param_name' => 'scroll_carousel_init',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
				),
				/**
				* Data settings
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Data settings', 'cheshalo' ),
					'param_name' => 'data_divider'
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Categories', 'cheshalo' ),
					'param_name' => 'categories',
					'value' => cheshalo_get_projects_cats_array(),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'cheshalo' ),
					'param_name' => 'orderby',
					'value' => array(
						'',
						esc_html__( 'Date', 'cheshalo' ) => 'date',
						esc_html__( 'ID', 'cheshalo' ) => 'ID',
						esc_html__( 'Title', 'cheshalo' ) => 'title',
						esc_html__( 'Modified', 'cheshalo' ) => 'modified',
						esc_html__( 'Menu order', 'cheshalo' ) => 'menu_order',
					),
					'save_always' => true,
					'hint' => sprintf( wp_kses(  __( 'Select how to sort retrieved projects. More at %s.', 'cheshalo' ), array(
	                        'a' => array( 
	                            'href' => array(), 
	                            'target' => array()
	                        )
                    	)), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Sort order', 'cheshalo' ),
					'param_name' => 'order',
					'value' => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						esc_html__( 'Descending', 'cheshalo' ) => 'DESC',
						esc_html__( 'Ascending', 'cheshalo' ) => 'ASC',
					),
					'save_always' => true,
					'hint' => sprintf( wp_kses(  __( 'Designates the ascending or descending order. More at %s.', 'cheshalo' ), array(
	                        'a' => array( 
	                            'href' => array(), 
	                            'target' => array()
	                        )
                    	)), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Pagination', 'cheshalo' ),
					'param_name' => 'pagination',
					'value' => array(
	                    '' => '',
	                    esc_html__( 'Pagination', 'cheshalo' ) => 'pagination',
	                    wp_kses( __( 'Load more button', 'cheshalo' ), 'entities' ) => 'load_more',
	                    esc_html__( 'Infinit', 'cheshalo' ) => 'infinit',
	                    esc_html__( 'Disable', 'cheshalo' ) => 'disable',
					),
					'dependency'       => array(
						'element' => 'layout',
						'value' => 'grid',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Extra
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Design', 'cheshalo' ),
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Style', 'cheshalo' ),
					'param_name' => 'style',
					'value' => array( 
						esc_html__( 'Inherit from Theme Settings', 'cheshalo' ) => 'inherit',
						esc_html__( 'Show text on mouse over', 'cheshalo' ) => 'hover',
						esc_html__( 'Alternative', 'cheshalo' ) => 'hover-inverse',
						esc_html__( 'Text under image', 'cheshalo' ) => 'text-shown',
						esc_html__( 'Mouse move parallax', 'cheshalo' ) => 'parallax',
					),
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'images_value' => array(
						'inherit' => CHESHALO_ASSETS_IMAGES . '/settings/empty.jpg',
						'hover' => CHESHALO_ASSETS_IMAGES . '/settings/portfolio/hover.jpg',
						'hover-inverse' => CHESHALO_ASSETS_IMAGES . '/settings/portfolio/hover-inverse.jpg',
						'text-shown' => CHESHALO_ASSETS_IMAGES . '/settings/portfolio/text-shown.jpg',
						'parallax' => CHESHALO_ASSETS_IMAGES . '/settings/portfolio/hover.jpg',
					),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Images size', 'cheshalo' ),
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'param_name' => 'image_size',
					'hint' => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Extra
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Lazy loading for images', 'cheshalo' ),
					'hint' => esc_html__( 'Enable lazy loading for images for this element.', 'cheshalo' ),
					'param_name' => 'lazy_loading',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				),
			),
		) );
	}
	add_action( 'vc_before_init', 'cheshalo_vc_map_portfolio' );
}
