<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
* Product filters
* ------------------------------------------------------------------------------------------------
*/

if ( ! function_exists( 'cheshalo_vc_map_product_filters' ) ) {
	function cheshalo_vc_map_product_filters() {
		if ( ! shortcode_exists( 'cheshalo_product_filters' ) ) {
			return;
		}

		$attribute_array = array( '' => '' );

		if ( function_exists( 'wc_get_attribute_taxonomies' ) ) {
			$attribute_taxonomies = wc_get_attribute_taxonomies();

			if ( $attribute_taxonomies ) {
				foreach ( $attribute_taxonomies as $tax ) {
					$attribute_array[ $tax->attribute_name ] = $tax->attribute_name;
				}
			}
		}

        //Product filter parent element
		vc_map( array(
			'name' => esc_html__( 'Product filters', 'cheshalo' ),
			'base' => 'cheshalo_product_filters',
			'class' => '',
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'Add filters by category, attribute or price', 'cheshalo' ),
            'icon' => CHESHALO_ASSETS . '/images/vc-icon/product-filter.svg',
            'as_parent' => array( 'only' => 'cheshalo_filter_categories, cheshalo_filters_attribute, cheshalo_filters_price_slider, cheshalo_stock_status, cheshalo_filters_orderby' ),
			'content_element' => true,
			'show_settings_on_create' => true,
			'params' => array(
				cheshalo_get_color_scheme_param(),
				array(
					'type' => 'css_editor',
					'heading' => esc_html__( 'CSS box', 'cheshalo' ),
					'param_name' => 'css',
					'group' => esc_html__( 'Design Options', 'cheshalo' )
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
            ),
			'js_view' => 'VcColumnView'
        ) );

        //Product filter categories
        vc_map( array(
			'name' => esc_html__( 'Filter categories', 'cheshalo'),
			'base' => 'cheshalo_filter_categories',
			'as_child' => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'icon' => CHESHALO_ASSETS . '/images/vc-icon/product-filter-categories.svg',
			'params' => array(
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'General options', 'cheshalo' ),
					'param_name' => 'general_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'cheshalo' ),
					'param_name' => 'order_by',
					'value' => array(
						esc_html__( 'Name', 'cheshalo' ) => 'name',
						esc_html__( 'ID', 'cheshalo' ) => 'ID',
						esc_html__( 'Slug', 'cheshalo' ) => 'slug',
						esc_html__( 'Count', 'cheshalo' ) => 'count',
						esc_html__( 'Category order', 'cheshalo' ) => 'order',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Show hierarchy', 'cheshalo' ),
					'param_name' => 'hierarchical',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 1,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Hide empty categories', 'cheshalo' ),
					'param_name' => 'hide_empty',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 0,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Show current category ancestors', 'cheshalo' ),
					'param_name' => 'show_categories_ancestors',
					'hint' => esc_html__( 'If you visit category Man, for example, only man\'s subcategories will be shown in the page title like T-shirts, Coats, Shoes etc.', 'cheshalo' ),
					'true_state' => 1,
					'false_state' => 0,
					'default' => 0,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			),
        ) );
        
        //Product filter attribute
        vc_map( array(
			'name' => esc_html__( 'Filter attribute', 'cheshalo'),
			'base' => 'cheshalo_filters_attribute',
			'as_child' => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'icon' => CHESHALO_ASSETS . '/images/vc-icon/product-filter-atribute.svg',
			'params' => array(
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'General options', 'cheshalo' ),
					'param_name' => 'general_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Attribute', 'cheshalo' ),
					'param_name' => 'attribute',
					'value' => $attribute_array,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'autocomplete',
					'heading' => esc_html__( 'Show in categories', 'cheshalo' ),
					'param_name' => 'categories',
					'settings' => array(
						'multiple' => true,
						'sortable' => true,
					),
					'save_always' => true,
					'hint' => esc_html__( 'Choose on which categories pages you want to display this filter. Or leave empty to show on all pages.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Query type', 'cheshalo' ),
					'param_name' => 'query_type',
					'hint' => esc_html__( 'If you select “AND”, you will be allowed to select only one attribute. In case of “OR”, you will be able to select multiple values.', 'cheshalo' ),
					'value' => array(
						esc_html__( 'AND', 'cheshalo' ) => 'and',
						esc_html__( 'OR', 'cheshalo' ) => 'or',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Swatches size', 'cheshalo' ),
					'param_name' => 'size',
					'value' => array(
						esc_html__( 'Normal (25px)', 'cheshalo' ) => 'normal',
						esc_html__( 'Small (15px)', 'cheshalo' ) => 'small',
						esc_html__( 'Large (35px)', 'cheshalo' ) => 'large',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			),
        ) );

		vc_map( array(
			'name' => esc_html__( 'Stock status', 'cheshalo'),
			'base' => 'cheshalo_stock_status',
			'as_child' => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'icon' => CHESHALO_ASSETS . '/images/vc-icon/product-filter-atribute.svg',
			'params' => array(
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'General options', 'cheshalo' ),
					'param_name' => 'general_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'On Sale filter', 'cheshalo' ),
					'param_name' => 'onsale',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 1,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'In Stock filter', 'cheshalo' ),
					'param_name' => 'instock',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 1,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Show labels', 'cheshalo' ),
					'param_name' => 'labels',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 1,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			),
		) );
        
        //Product filter price
        vc_map( array(
			'name' => esc_html__( 'Filter price', 'cheshalo'),
			'base' => 'cheshalo_filters_price_slider',
			'as_child' => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'icon' => CHESHALO_ASSETS . '/images/vc-icon/product-filter-price.svg',
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			),
		) );

        // Order by
		vc_map( array(
			'name' => esc_html__( 'Order by', 'cheshalo'),
			'base' => 'cheshalo_filters_orderby',
			'as_child' => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'icon' => CHESHALO_ASSETS . '/images/vc-icon/product-filter-atribute.svg',
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			),
		) );
        
        // A must for container functionality, replace Wbc_Item with your base name from mapping for parent container
		if ( class_exists( 'WPBakeryShortCodesContainer' ) ){
			class WPBakeryShortCode_cheshalo_product_filters extends WPBakeryShortCodesContainer {}
		}

		// Replace Wbc_Inner_Item with your base name from mapping for nested element
		if ( class_exists( 'WPBakeryShortCode' ) ){
			class WPBakeryShortCode_cheshalo_filter_categories extends WPBakeryShortCode {}
		}

		// Replace Wbc_Inner_Item with your base name from mapping for nested element
		if ( class_exists( 'WPBakeryShortCode' ) ){
			class WPBakeryShortCode_cheshalo_filters_attribute extends WPBakeryShortCode {}
		}

		// Replace Wbc_Inner_Item with your base name from mapping for nested element
		if ( class_exists( 'WPBakeryShortCode' ) ){
			class WPBakeryShortCode_cheshalo_filters_price_slider extends WPBakeryShortCode {}
		}

		if ( class_exists( 'WPBakeryShortCode' ) ){
			class WPBakeryShortCode_cheshalo_filters_orderby extends WPBakeryShortCode {}
		}
		
		if ( class_exists( 'WPBakeryShortCode' ) ){
			class WPBakeryShortCode_cheshalo_stock_status extends WPBakeryShortCode {}
		}

		add_filter( 'vc_autocomplete_cheshalo_filters_attribute_categories_callback', 'cheshalo_productCategoryCategoryAutocompleteSuggester', 10, 1 ); 
		
		add_filter( 'vc_autocomplete_cheshalo_filters_attribute_categories_render', 'cheshalo_productCategoryCategoryRenderByIdExact', 10, 1 ); 

    }

	add_action( 'vc_before_init', 'cheshalo_vc_map_product_filters' );
}
