<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
* AJAX Products tabs element map
* ------------------------------------------------------------------------------------------------
*/

if( ! function_exists( 'cheshalo_vc_map_products_tabs' ) ) {
	function cheshalo_vc_map_products_tabs() {
		if ( ! shortcode_exists( 'products_tabs' ) ) {
			return;
		}
		
		vc_map( array(
			'name' => esc_html__( 'AJAX Products tabs', 'cheshalo' ),
			'base' => 'products_tabs',
			'as_parent' => array( 'only' => 'products_tab' ),
			'content_element' => true,
			'show_settings_on_create' => true,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'Product tabs for your marketplace', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/ajax-products-tabs.svg',
			'params' => array(
				array(
					'type' => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id'
				),
				/**
				* Title
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Tabs title', 'cheshalo' ),
					'param_name' => 'title',
				),
				/**
				* Image
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Image settings', 'cheshalo' ),
					'param_name' => 'image_divider'
				),
				array(
					'type' => 'attach_image',
					'heading' => esc_html__( 'Icon image', 'cheshalo' ),
					'param_name' => 'image',
					'value' => '',
					'hint' => esc_html__( 'Select image from media library.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Images size', 'cheshalo' ),
					'param_name' => 'img_size',
					'hint' => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
				),
				/**
				* Style
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Style', 'cheshalo' ),
					'param_name' => 'style_divider'
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Tabs color', 'cheshalo' ),
					'param_name' => 'color',
					'css_args' => array(
						'color' => array(
							'.tabs-design-simple .products-tabs-title li.active-tab-title',
							'.tabs-design-simple .owl-nav > div:hover',
							'.tabs-design-simple .wrap-loading-arrow > div:not(.disabled):hover',
						),
						'border-color' => array(
							'.tabs-design-simple .tabs-name'
						),
						'background-color' => array(
							'.tabs-design-default .products-tabs-title .tab-label:after',
							'.tabs-design-alt .products-tabs-title .tab-label:after',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Design', 'cheshalo' ),
					'param_name' => 'design',
					'value' => array( 
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Simple', 'cheshalo' ) => 'simple',
						esc_html__( 'Alternative', 'cheshalo' ) => 'alt',
					),
					'images_value' => array(
						'default' => CHESHALO_ASSETS_IMAGES . '/settings/ajax-tabs/default.png',
						'simple' => CHESHALO_ASSETS_IMAGES . '/settings/ajax-tabs/simple.png',
						'alt' => CHESHALO_ASSETS_IMAGES . '/settings/ajax-tabs/alternative.png',
					),
					'std' => 'default',
					'wood_tooltip' => true,
					'edit_field_class' => 'vc_col-xs-12 vc_column tab-design',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Alignment', 'cheshalo' ),
					'group' => esc_html__( 'Layouts', 'cheshalo' ),
					'param_name' => 'alignment',
					'value' => array(
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images_value' => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left' => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right' => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'dependency' => array(
						'element' => 'design',
						'value' => array( 'default' )
					),
					'std' => 'center',
					'wood_tooltip' => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
			),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			),
		    'js_view' => 'VcColumnView'
		) );

		$cheshalo_prdoucts_params = vc_map_integrate_shortcode( cheshalo_get_products_shortcode_map_params(), '', '', array(
			'exclude' => array(
				'highlighted_products',
				'element_title',
				'source_divider',
				'shop_tools'
			),
		) );

		vc_map( array(
			'name' => esc_html__( 'Products tab', 'cheshalo' ),
			'base' => 'products_tab',
			'as_child' => array( 'only' => 'products_tabs' ),
			'content_element' => true,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'Products block', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/product-categories.svg',
			'params' => array_merge( array(
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'image_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title for the tab', 'cheshalo' ),
					'param_name' => 'title'
				),
				/**
				* Icon
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Icon', 'cheshalo' ),
					'param_name' => 'icon_divider'
				),
				array(
					'type' => 'attach_image',
					'heading' => esc_html__( 'Icon for the tab', 'cheshalo' ),
					'param_name' => 'icon',
					'hint' => esc_html__( 'Select icon from media library.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Icon size', 'cheshalo' ),
					'param_name' => 'icon_size',
					'hint' => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
				)
			), $cheshalo_prdoucts_params )
		) );

		// Necessary hooks for blog autocomplete fields
		add_filter( 'vc_autocomplete_products_tab_include_callback',	'vc_include_field_search', 10, 1 ); // Get suggestion(find). Must return an array
		add_filter( 'vc_autocomplete_products_tab_include_render',
			'vc_include_field_render', 10, 1 ); // Render exact product. Must return an array (label,value)

		// Narrow data taxonomies
		add_filter( 'vc_autocomplete_products_tab_taxonomies_callback', 'cheshalo_vc_autocomplete_taxonomies_field_search', 10, 1 );
		add_filter( 'vc_autocomplete_products_tab_taxonomies_render', 'cheshalo_vc_autocomplete_taxonomies_field_render', 10, 1 );

		// Narrow data taxonomies for exclude_filter
		add_filter( 'vc_autocomplete_products_tab_exclude_filter_callback', 'vc_autocomplete_taxonomies_field_search', 10, 1 );
		add_filter( 'vc_autocomplete_products_tab_exclude_filter_render', 'vc_autocomplete_taxonomies_field_render', 10, 1 );

		add_filter( 'vc_autocomplete_products_tab_exclude_callback',	'vc_exclude_field_search', 10, 1 ); // Get suggestion(find). Must return an array
		add_filter( 'vc_autocomplete_products_tab_exclude_render', 'vc_exclude_field_render', 10, 1 ); // Render exact product. Must return an array (label,value)
	}
	add_action( 'vc_before_init', 'cheshalo_vc_map_products_tabs' );
}

// A must for container functionality, replace Wbc_Item with your base name from mapping for parent container
if( class_exists( 'WPBakeryShortCodesContainer' ) ){
    class WPBakeryShortCode_products_tabs extends WPBakeryShortCodesContainer {

    }
}

// Replace Wbc_Inner_Item with your base name from mapping for nested element
if( class_exists( 'WPBakeryShortCode' ) ){
    class WPBakeryShortCode_products_tab extends WPBakeryShortCode {

    }
}
