<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
* AJAX Products tabs element map
* ------------------------------------------------------------------------------------------------
*/

if( ! function_exists( 'cheshalo_vc_map_products' ) ) {
	function cheshalo_vc_map_products() {
		if ( ! shortcode_exists( 'cheshalo_products' ) ) {
			return;
		}

		vc_map( cheshalo_get_products_shortcode_map_params() );
	}
	add_action( 'vc_before_init', 'cheshalo_vc_map_products' );
}

if( ! function_exists( 'cheshalo_get_products_shortcode_params' ) ) {
	function cheshalo_get_products_shortcode_map_params() {
		return array(
			'name' => esc_html__( 'Products (grid or carousel)', 'cheshalo' ),
			'base' => 'cheshalo_products',
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'Animated carousel with posts', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/products-grid-or-carousel.svg',
			'params' => cheshalo_get_products_shortcode_params()
		);
	}
}

if( ! function_exists( 'cheshalo_get_products_shortcode_params' ) ) {
	function cheshalo_get_products_shortcode_params() {
		return apply_filters( 'cheshalo_get_products_shortcode_params', array(
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Element title', 'cheshalo' ),
					'param_name' => 'element_title',
				),
				/**
				* Product source
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Product source', 'cheshalo' ),
					'param_name' => 'source_divider'
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Data source', 'cheshalo' ),
					'param_name' => 'post_type',
					'value' =>  array(
						array( 'product', esc_html__( 'All Products', 'cheshalo' ) ),
						array( 'featured', esc_html__( 'Featured Products', 'cheshalo' ) ),
						array( 'sale', esc_html__( 'Sale Products', 'cheshalo' ) ),
						array( 'new', esc_html__( 'Products with NEW label', 'cheshalo' ) ),
						array( 'bestselling', esc_html__( 'Bestsellers', 'cheshalo' ) ),
						array( 'ids', esc_html__( 'List of IDs', 'cheshalo' ) ),
						array( 'top_rated_products', esc_html__( 'Top Rated Products', 'cheshalo' ) )
					),
					'hint' => esc_html__( 'Select content type for your grid.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'autocomplete',
					'heading' => esc_html__( 'Include only', 'cheshalo' ),
					'param_name' => 'include',
					'hint' => esc_html__( 'Add products by title.', 'cheshalo' ),
					'settings' => array(
						'multiple' => true,
						'sortable' => true,
						'groups' => true
					),
					'dependency' => array(
						'element' => 'post_type',
						'value' => array( 'ids' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				// Custom query tab
				array(
					'type' => 'textarea_safe',
					'heading' => esc_html__( 'Custom query', 'cheshalo' ),
					'param_name' => 'custom_query',
					'hint' => wp_kses(  __( 'Build custom query according to <a href="http://codex.wordpress.org/Function_Reference/query_posts">WordPress Codex</a>.', 'cheshalo' ), array(
	                        'a' => array( 
	                            'href' => array(), 
	                            'target' => array()
	                        )
                    	) ),
					'dependency' => array(
						'element' => 'post_type',
						'value' => array( 'custom' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'autocomplete',
					'heading' => esc_html__( 'Categories or tags', 'cheshalo' ),
					'param_name' => 'taxonomies',
					'settings' => array(
						'multiple' => true,
						// is multiple values allowed? default false
						// 'sortable' => true, // is values are sortable? default false
						'min_length' => 1,
						// min length to start search -> default 2
						// 'no_hide' => true, // In UI after select doesn't hide an select list, default false
						'groups' => true,
						// In UI show results grouped by groups, default false
						'unique_values' => true,
						// In UI show results except selected. NB! You should manually check values in backend, default false
						'display_inline' => true,
						// In UI show results inline view, default false (each value in own line)
						'delay' => 500,
						// delay for search. default 500
						'auto_focus' => true,
						// auto focus input, default true
					),
					'param_holder_class' => 'vc_not-for-custom',
					'hint' => esc_html__( 'Enter categories, tags or custom taxonomies.', 'cheshalo' ),
					'dependency' => array(
						'element' => 'post_type',
						'value_not_equal_to' => array( 'ids', 'custom' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Layout
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout_divider'
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Grid or carousel', 'cheshalo' ),
					'param_name' => 'layout',
					'value' =>  array(
						esc_html__( 'Grid', 'cheshalo' ) => 'grid',
	                    esc_html__( 'List', 'cheshalo' ) => 'list',
	                    esc_html__( 'Carousel', 'cheshalo' ) => 'carousel',
					),
					'hint' => esc_html__( 'Show products in standard grid or via slider carousel', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_slider',
					'heading' => esc_html__( 'Columns', 'cheshalo' ),
					'param_name' => 'columns',
					'min' => '1',
					'max' => '6',
					'step' => '1',
					'default' => '4',
					'units' => '',
					'hint' => esc_html__( 'Number of columns in the grid.', 'cheshalo' ),
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'grid' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Masonry grid', 'cheshalo' ), 
					'param_name' => 'products_masonry',
					'hint' => esc_html__( 'Products may have different sizes', 'cheshalo' ),
					'value' => array(
	                    esc_html__( 'Inherit', 'cheshalo' ) => '',
	                    esc_html__( 'Enable', 'cheshalo' ) => 'enable',
	                    esc_html__( 'Disable', 'cheshalo' ) => 'disable'
					),
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'grid' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Products grid with different sizes', 'cheshalo' ), 
					'hint' => esc_html__( 'In this situation, some of the products will be twice bigger in width than others. Recommended to use with 6 columns grid only.', 'cheshalo' ), 
					'param_name' => 'products_different_sizes',
					'value' => array(
	                    esc_html__( 'Inherit', 'cheshalo' ) => '',
	                    esc_html__( 'Enable', 'cheshalo' ) => 'enable',
	                    esc_html__( 'Disable', 'cheshalo' ) => 'disable'
					),
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'grid' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Space between products', 'cheshalo' ),
					'param_name' => 'spacing',
					'value' => array(
						'', 30,20,10,6,2,0
					),
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'grid', 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Carousel
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Carousel', 'cheshalo' ),
					'param_name' => 'carousel_divider',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
				),
				array(
					'type' => 'cheshalo_slider',
					'heading' => esc_html__( 'Slides per view', 'cheshalo' ),
					'param_name' => 'slides_per_view',
					'min' => '1',
					'max' => '8',
					'step' => '1',
					'default' => '4',
					'units' => '',
					'hint' => esc_html__( 'Set numbers of slides you want to display at the same time on slider\'s container for carousel mode. Also supports for "auto" value, in this case it will fit slides depending on container\'s width. "auto" mode doesn\'t compatible with loop mode.', 'cheshalo' ),
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Scroll per page', 'cheshalo' ),
					'param_name' => 'scroll_per_page',
					'hint' => esc_html__( 'Scroll per page not per item. This affect next/prev buttons and mouse/touch dragging.', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'std' => 'yes',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Slider autoplay', 'cheshalo' ),
					'param_name' => 'autoplay',
					'hint' => esc_html__( 'Enables autoplay mode.', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Slider speed', 'cheshalo' ),
					'param_name' => 'speed',
					'value' => '5000',
					'hint' => esc_html__( 'Duration of animation between slides (in ms)', 'cheshalo' ),
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Hide pagination control', 'cheshalo' ),
					'param_name' => 'hide_pagination_control',
					'hint' => esc_html__( 'If "YES" pagination control will be removed', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Hide prev/next buttons', 'cheshalo' ),
					'param_name' => 'hide_prev_next_buttons',
					'hint' => esc_html__( 'If "YES" prev/next control will be removed', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Center mode', 'cheshalo' ),
					'param_name' => 'center_mode',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Slider loop', 'cheshalo' ),
					'param_name' => 'wrap',
					'hint' => esc_html__( 'Enables loop mode.', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Pagination
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Pagination', 'cheshalo' ),
					'param_name' => 'pagination_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Items per page', 'cheshalo' ),
					'param_name' => 'items_per_page',
					'hint' => esc_html__( 'Number of items to show per page.', 'cheshalo' ),
					'value' => '12',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Pagination', 'cheshalo' ),
					'param_name' => 'pagination',
					'value' => array(
	                    esc_html__( 'Inherit', 'cheshalo' ) => '',
	                    wp_kses( __( 'Load more button', 'cheshalo' ), 'entities' ) => 'more-btn',
	                    esc_html__( 'Infinit scrolling', 'cheshalo' ) => 'infinit',
	                    esc_html__( 'Arrows', 'cheshalo' ) => 'arrows',
	                    esc_html__( 'Links', 'cheshalo' ) => 'links'
					),
					'dependency' => array(
						'element' => 'layout',
						'value_not_equal_to' => array( 'carousel' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Shop tools', 'cheshalo' ),
					'hint' => esc_html__( 'Per page, Sorting, Columns', 'cheshalo' ),
					'param_name' => 'shop_tools',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'pagination',
						'value' => array( 'links' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Design
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Design', 'cheshalo' ),
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'param_name' => 'design_divider'
				),
				array(
				    'type' => 'cheshalo_image_select',
				    'heading' => esc_html__( 'Products hover', 'cheshalo' ),
				    'param_name' => 'product_hover',
				    'value' => array( 
						esc_html__( 'Inherit from Theme Settings', 'cheshalo' ) => 'inherit',
						esc_html__( 'Full info on hover', 'cheshalo' ) => 'info-alt',
						esc_html__( 'Full info on image', 'cheshalo' ) => 'info',
						esc_html__( 'Icons and "add to cart" on hover', 'cheshalo' ) => 'alt',
						esc_html__( 'Icons on hover', 'cheshalo' ) => 'icons',
						esc_html__( 'Quick', 'cheshalo' ) => 'quick',
						esc_html__( 'Show button on hover on image', 'cheshalo' ) => 'button',
						esc_html__( 'Show summary on hover', 'cheshalo' ) => 'base',
						esc_html__( 'Standard button', 'cheshalo' ) => 'standard',
						esc_html__( 'Tiled', 'cheshalo' ) => 'tiled',
					),
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'images_value' => array(
						'inherit' => CHESHALO_ASSETS_IMAGES . '/settings/empty.jpg',
						'info-alt' => CHESHALO_ASSETS_IMAGES . '/settings/hover/info-alt.jpg',
						'info' => CHESHALO_ASSETS_IMAGES . '/settings/hover/info.jpg',
						'alt' => CHESHALO_ASSETS_IMAGES . '/settings/hover/alt.jpg',
						'icons' => CHESHALO_ASSETS_IMAGES . '/settings/hover/icons.jpg',
						'quick' => CHESHALO_ASSETS_IMAGES . '/settings/hover/quick.jpg',
						'button' => CHESHALO_ASSETS_IMAGES . '/settings/hover/button.jpg',
						'base' => CHESHALO_ASSETS_IMAGES . '/settings/hover/base.jpg',
						'standard' => CHESHALO_ASSETS_IMAGES . '/settings/hover/standard.jpg',
						'tiled' => CHESHALO_ASSETS_IMAGES . '/settings/hover/tiled.jpg',
					),
				    'dependency' => array(
				        'element' => 'layout',
				        'value_not_equal_to' => array( 'list' )
				    )
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Images size', 'cheshalo' ),
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'param_name' => 'img_size',
					'hint' => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Sale countdown', 'cheshalo' ),
					'hint' => esc_html__( 'Countdown to the end sale date will be shown. Be sure you have set final date of the product sale price.', 'cheshalo' ),
					'param_name' => 'sale_countdown',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 0,
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Stock progress bar', 'cheshalo' ),
					'hint' => esc_html__( 'Display a number of sold and in stock products as a progress bar.', 'cheshalo' ),
					'param_name' => 'stock_progress_bar',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 0,
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Highlighted products', 'cheshalo' ),
					'hint' => esc_html__( 'Create an eye-catching section of special products to promote them on your store.', 'cheshalo' ),
					'param_name' => 'highlighted_products',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 0,
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Bordered grid', 'cheshalo' ),
					'hint' => esc_html__( 'Add borders between the products in your grid', 'cheshalo' ),
					'param_name' => 'products_bordered_grid',
					'true_state' => 1,
					'false_state' => 0,
					'default' => 0,
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Quantity input on product', 'cheshalo' ),
					'param_name' => 'product_quantity',
					'value' => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						esc_html__( 'Enable', 'cheshalo' ) => 'enable',
						esc_html__( 'Disable', 'cheshalo' ) => 'disable'
					),
					'group' => esc_html__( 'Design', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency' => array(
						'element' => 'product_hover',
						'value' => array( 'standard', 'quick' ),
					),
				),
				/**
				* Data settings
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Data settings', 'cheshalo' ),
					'group' => esc_html__( 'Data Settings', 'cheshalo' ),
					'param_name' => 'data_tab_divider',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'cheshalo' ),
					'param_name' => 'orderby',
					'value' => array(
						'',
						esc_html__( 'Date', 'cheshalo' ) => 'date',
						esc_html__( 'Order by post ID', 'cheshalo' ) => 'ID',
						esc_html__( 'Author', 'cheshalo' ) => 'author',
						esc_html__( 'Title', 'cheshalo' ) => 'title',
						esc_html__( 'Last modified date', 'cheshalo' ) => 'modified',
						esc_html__( 'Number of comments', 'cheshalo' ) => 'comment_count',
						esc_html__( 'Menu order/Page Order', 'cheshalo' ) => 'menu_order',
						esc_html__( 'Meta value', 'cheshalo' ) => 'meta_value',
						esc_html__( 'Meta value number', 'cheshalo' ) => 'meta_value_num',
						esc_html__( 'Matches same order you passed in via the include parameter.', 'cheshalo') => 'post__in',
						esc_html__( 'Random order', 'cheshalo' ) => 'rand',
						esc_html__( 'Price', 'cheshalo' ) => 'price'
					),
					'hint' => esc_html__( 'Select order type. If "Meta value" or "Meta value Number" is chosen then meta key is required.', 'cheshalo' ),
					'group' => esc_html__( 'Data Settings', 'cheshalo' ),
					'param_holder_class' => 'vc_grid-data-type-not-ids',
					'dependency' => array(
						'element' => 'post_type',
						'value_not_equal_to' => array( 'custom' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Offset', 'cheshalo' ),
					'param_name' => 'offset',
					'hint' => esc_html__( 'Number of grid elements to displace or pass over.', 'cheshalo' ),
					'group' => esc_html__( 'Data Settings', 'cheshalo' ),
					'param_holder_class' => 'vc_grid-data-type-not-ids',
					'dependency' => array(
						'element' => 'post_type',
						'value_not_equal_to' => array( 'ids', 'custom' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Query type', 'cheshalo' ),
					'param_name' => 'query_type',
					'group' => esc_html__( 'Data Settings', 'cheshalo' ),
					'value' => array(
						esc_html__( 'OR', 'cheshalo' ) => 'OR',
						esc_html__( 'AND', 'cheshalo' ) => 'AND'
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Sorting', 'cheshalo' ),
					'param_name' => 'order',
					'group' => esc_html__( 'Data Settings', 'cheshalo' ),
					'value' => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						esc_html__( 'Descending', 'cheshalo' ) => 'DESC',
						esc_html__( 'Ascending', 'cheshalo' ) => 'ASC'
					),
					'param_holder_class' => 'vc_grid-data-type-not-ids',
					'hint' => esc_html__( 'Select sorting order.', 'cheshalo' ),
					'dependency' => array(
						'element' => 'post_type',
						'value_not_equal_to' => array( 'ids', 'custom' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Meta key', 'cheshalo' ),
					'param_name' => 'meta_key',
					'hint' => esc_html__( 'Input meta key for grid ordering.', 'cheshalo' ),
					'group' => esc_html__( 'Data Settings', 'cheshalo' ),
					'param_holder_class' => 'vc_grid-data-type-not-ids',
					'dependency' => array(
						'element' => 'orderby',
						'value' => array( 'meta_value', 'meta_value_num' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'autocomplete',
					'heading' => esc_html__( 'Exclude', 'cheshalo' ),
					'param_name' => 'exclude',
					'hint' => esc_html__( 'Exclude posts, pages, etc. by title.', 'cheshalo' ),
					'group' => esc_html__( 'Data Settings', 'cheshalo' ),
					'settings' => array(
						'multiple' => true,
					),
					'param_holder_class' => 'vc_grid-data-type-not-ids',
					'dependency' => array(
						'element' => 'post_type',
						'value_not_equal_to' => array( 'ids', 'custom' ),
						'callback' => 'vc_grid_exclude_dependency_callback',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Extra
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Lazy loading for images', 'cheshalo' ),
					'hint' => esc_html__( 'Enable lazy loading for images for this element.', 'cheshalo' ),
					'param_name' => 'lazy_loading',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Init carousel on scroll', 'cheshalo' ),
					'hint' => esc_html__( 'This option allows you to init carousel script only when visitor scroll the page to the slider. Useful for performance optimization.', 'cheshalo' ),
					'param_name' => 'scroll_carousel_init',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'carousel' ),
					),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			)
		);
	}
}

// Necessary hooks for blog autocomplete fields
add_filter( 'vc_autocomplete_cheshalo_products_include_callback',	'cheshalo_productIdAutocompleteSuggester_new', 10, 1 ); // Get suggestion(find). Must return an array
add_filter( 'vc_autocomplete_cheshalo_products_include_render',
	'cheshalo_productIdAutocompleteRender', 10, 1 ); // Render exact product. Must return an array (label,value)

// Narrow data taxonomies
add_filter( 'vc_autocomplete_cheshalo_products_taxonomies_callback', 'cheshalo_vc_autocomplete_taxonomies_field_search', 10, 1 );
add_filter( 'vc_autocomplete_cheshalo_products_taxonomies_render', 'cheshalo_vc_autocomplete_taxonomies_field_render', 10, 1 );

// Narrow data taxonomies for exclude_filter
add_filter( 'vc_autocomplete_cheshalo_products_exclude_filter_callback', 'vc_autocomplete_taxonomies_field_search', 10, 1 );
add_filter( 'vc_autocomplete_cheshalo_products_exclude_filter_render', 'vc_autocomplete_taxonomies_field_render', 10, 1 );

add_filter( 'vc_autocomplete_cheshalo_products_exclude_callback',	'vc_exclude_field_search', 10, 1 ); // Get suggestion(find). Must return an array
add_filter( 'vc_autocomplete_cheshalo_products_exclude_render', 'vc_exclude_field_render', 10, 1 ); // Render exact product. Must return an array (label,value)

if( ! function_exists( 'cheshalo_vc_autocomplete_taxonomies_field_render' ) ) {
	function cheshalo_vc_autocomplete_taxonomies_field_render( $term ) {
		$vc_taxonomies_types = vc_taxonomies_types();

		$brands_attribute = cheshalo_get_opt( 'brands_attribute' );

		if( !empty( $brands_attribute ) && taxonomy_exists( $brands_attribute ) ) {
			$vc_taxonomies_types[ $brands_attribute ] = $brands_attribute;
		}

		$terms = get_terms( array_keys( $vc_taxonomies_types ), array(
			'include' => array( $term['value'] ),
			'hide_empty' => false,
		) );
		$data = false;
		if ( is_array( $terms ) && 1 === count( $terms ) ) {
			$term = $terms[0];
			$data = vc_get_term_object( $term );
		}

		return $data;
	}
}

// Add other product attributes
if( ! function_exists( 'cheshalo_vc_autocomplete_taxonomies_field_search' ) ) {
	function cheshalo_vc_autocomplete_taxonomies_field_search( $search_string ) {
		$data = array();
		$vc_filter_by = vc_post_param( 'vc_filter_by', '' );
		$vc_taxonomies_types = strlen( $vc_filter_by ) > 0 ? array( $vc_filter_by ) : array_keys( vc_taxonomies_types() );

		$brands_attribute = cheshalo_get_opt( 'brands_attribute' );

		if( !empty( $brands_attribute ) && taxonomy_exists( $brands_attribute ) ) {
			array_push($vc_taxonomies_types, $brands_attribute);
		}

		$vc_taxonomies = get_terms( $vc_taxonomies_types, array(
			'hide_empty' => false,
			'search' => $search_string,
		) );
		if ( is_array( $vc_taxonomies ) && ! empty( $vc_taxonomies ) ) {
			foreach ( $vc_taxonomies as $t ) {
				if ( is_object( $t ) ) {
					$data[] = vc_get_term_object( $t );
				}
			}
		}

		return $data;
	}
}
