<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
* Testimonials element map
* ------------------------------------------------------------------------------------------------
*/

if( ! function_exists( 'cheshalo_vc_map_testimonials' ) ) {
	function cheshalo_vc_map_testimonials() {
		if ( ! shortcode_exists( 'testimonials' ) ) {
			return;
		}
		
		vc_map( array(
			'name' => esc_html__( 'Testimonials', 'cheshalo' ),
			'base' => 'testimonials',
			'as_parent' => array( 'only' => 'testimonial' ),
			'content_element' => true,
			'show_settings_on_create' => false,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'User testimonials slider or grid', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/testimonials.svg',
			'params' => array(
				array(
					'type' => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id'
				),
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Element title', 'cheshalo' ),
					'param_name' => 'title',
					'value' => '',
				),
				/**
				* Layout
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout_divider'
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout',
					'value' => array(
						esc_html__( 'Slider', 'cheshalo' ) => 'slider',
						esc_html__( 'Grid', 'cheshalo' ) => 'grid'
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				), 
				array(
					'type' => 'cheshalo_slider',
					'heading' => esc_html__( 'Columns', 'cheshalo' ),
					'param_name' => 'columns',
					'min' => '1',
					'max' => '6',
					'step' => '1',
					'default' => '3',
					'units' => '',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'grid' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Space between testimonial', 'cheshalo' ),
					'param_name' => 'spacing',
					'value' => array(
						30,20,10,6,2,0
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Slider
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Slider', 'cheshalo' ),
					'param_name' => 'slider_divider',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'slider' ),
					),
				),
				array(
					'type' => 'cheshalo_slider',
					'heading' => esc_html__( 'Slides per view', 'cheshalo' ),
					'param_name' => 'slides_per_view',
					'min' => '1',
					'max' => '8',
					'step' => '1',
					'default' => '3',
					'units' => '',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'slider' )
					),
					'hint' => esc_html__( 'Set numbers of slides you want to display at the same time on slider\'s container for carousel mode.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Slider autoplay', 'cheshalo' ),
					'param_name' => 'autoplay',
					'hint' => esc_html__( 'Enables autoplay mode.', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'slider' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Slider speed', 'cheshalo' ),
					'param_name' => 'speed',
					'value' => '5000',
					'hint' => esc_html__( 'Duration of animation between slides (in ms)', 'cheshalo' ),
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'slider' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Hide pagination control', 'cheshalo' ),
					'param_name' => 'hide_pagination_control',
					'hint' => esc_html__( 'If "YES" pagination control will be removed', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'slider' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Hide prev/next buttons', 'cheshalo' ),
					'param_name' => 'hide_prev_next_buttons',
					'hint' => esc_html__( 'If "YES" prev/next control will be removed', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'slider' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Center mode', 'cheshalo' ),
					'param_name' => 'center_mode',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'slider' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Slider loop', 'cheshalo' ),
					'param_name' => 'wrap',
					'hint' => esc_html__( 'Enables loop mode.', 'cheshalo' ),
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'no',
					'dependency' => array(
						'element' => 'layout',
						'value' => array( 'slider' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Style
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Style', 'cheshalo' ),
					'param_name' => 'style_divider'
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Style', 'cheshalo' ),
					'param_name' => 'style',
					'value' => array(
						esc_html__( 'Standard', 'cheshalo' ) => 'standard',
						esc_html__( 'Boxed', 'cheshalo' ) => 'boxed',
						esc_html__( 'Information top', 'cheshalo' ) => 'info-top'
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Text size', 'cheshalo' ),
					'param_name' => 'text_size',
					'value' => array(
						esc_html__( 'Default', 'cheshalo' ) => '',
						esc_html__( 'Small (14px)', 'cheshalo' ) => 'small',
						esc_html__( 'Medium (16px)', 'cheshalo' ) => 'medium',
						esc_html__( 'Large (18px)', 'cheshalo' ) => 'large'
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Text background color', 'cheshalo' ),
					'param_name' => 'text_background_color_normal',
					'css_args' => array(
						'background-color' => array(
							' .wd-testimon-text',
						),
						'border-bottom-color' => array(
							' .wd-testimon-text:before',
						),
					),
					'dependency'       => array(
						'element' => 'style',
						'value' => array( 'info-top' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Text color', 'cheshalo' ),
					'param_name' => 'text_color_normal',
					'css_args' => array(
						'color' => array(
							' .wd-testimon-text',
						),
					),
					'dependency'       => array(
						'element' => 'style',
						'value' => array( 'info-top' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Align', 'cheshalo' ),
					'param_name' => 'align',
				    'value' => array( 
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images_value' => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left' => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right' => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'dependency'       => array(
						'element'            => 'style',
						'value_not_equal_to' => array( 'info-top' ),
					),
					'std' => 'center',
					'wood_tooltip' => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				array(
					'type' => 'cheshalo_switch',
					'heading' => esc_html__( 'Display stars rating', 'cheshalo' ),
					'param_name' => 'stars_rating',
					'true_state' => 'yes',
					'false_state' => 'no',
					'default' => 'yes',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				* Extra
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			),
		    'js_view' => 'VcColumnView'
		) );

		vc_map( array(
			'name' => esc_html__( 'Testimonial', 'cheshalo' ),
			'base' => 'testimonial',
			'class' => '',
			'as_child' => array( 'only' => 'testimonials' ),
			'content_element' => true,
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'User testimonial', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/testimonials.svg',
			'params' => array(
				/**
				* Image
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Image', 'cheshalo' ),
					'param_name' => 'image_divider'
				),
				array(
					'type' => 'attach_image',
					'heading' => esc_html__( 'User Avatar', 'cheshalo' ),
					'param_name' => 'image',
					'value' => '',
					'hint' => esc_html__( 'Enter the person’s title or job position. For example: CEO or Senior Developer.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Image size', 'cheshalo' ),
					'param_name' => 'img_size',
					'hint' => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
				),
				/**
				* Content
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Content', 'cheshalo' ),
					'param_name' => 'content_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Name', 'cheshalo' ),
					'param_name' => 'name',
					'value' => '',
					'hint' => esc_html__( 'Enter the person’s name.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title',
					'value' => '',
					'hint' => esc_html__( 'User title', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textarea_html',
					'holder' => 'div',
					'heading' => esc_html__( 'Text', 'cheshalo' ),
					'param_name' => 'content'
				),
				/**
				* Extra
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			)
		) );
	}
	add_action( 'vc_before_init', 'cheshalo_vc_map_testimonials' );
}

if( class_exists( 'WPBakeryShortCodesContainer' ) ){
    class WPBakeryShortCode_testimonials extends WPBakeryShortCodesContainer {

    }
}

// Replace Wbc_Inner_Item with your base name from mapping for nested element
if( class_exists( 'WPBakeryShortCode' ) ){
    class WPBakeryShortCode_testimonial extends WPBakeryShortCode {

    }
}
