<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
* Section title element map
* ------------------------------------------------------------------------------------------------
*/

if ( ! function_exists( 'cheshalo_vc_map_title' ) ) {
	function cheshalo_vc_map_title() {
		if ( ! shortcode_exists( 'cheshalo_title' ) ) {
			return;
		}

		$secondary_font = cheshalo_get_opt( 'secondary-font' );
		$default_font = cheshalo_get_opt( 'text-font' );
		$alt_font_subtitle = isset( $secondary_font[0] ) ? esc_html__( 'Alternative', 'cheshalo' ) . ' (' . $secondary_font[0]['font-family'] . ')' : esc_html__( 'Alternative', 'cheshalo' );
		$default_font_subtitle = isset( $default_font[0] ) ? esc_html__( 'Default', 'cheshalo' ) . ' (' . $default_font[0]['font-family'] . ')' : esc_html__( 'Default', 'cheshalo' );

		vc_map( array(
			'name' => esc_html__( 'Section title', 'cheshalo' ),
			'base' => 'cheshalo_title',
			'category' => esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'Styled title for sections', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/section-title.svg',
			'params' => array(
				array(
					'type' => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id'
				),
				/**
				* Title
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title_divider'
				),
				array(
					'type' => 'textarea',
					'holder' => 'div',
					'heading' => esc_html__( 'Section title', 'cheshalo' ),
					'param_name' => 'title'
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Predefined title size', 'cheshalo' ),
					'param_name' => 'size',
					'value' => array(
						esc_html__( 'Default (22px)', 'cheshalo' ) => 'default',
						esc_html__( 'Small (18px)', 'cheshalo' ) => 'small',
						esc_html__( 'Medium (26px)', 'cheshalo' ) => 'medium',
						esc_html__( 'Large (36px)', 'cheshalo' ) => 'large',
						esc_html__( 'Extra Large (46px)', 'cheshalo' ) => 'extra-large',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Font weight', 'cheshalo' ),
					'param_name' => 'font_weight',
					'value' => array(
						'' => '',
						esc_html__( 'Ultra-Light 100', 'cheshalo' ) => 100,
						esc_html__( 'Light 200', 'cheshalo' ) => 200,
						esc_html__( 'Book 300', 'cheshalo' ) => 300,
						esc_html__( 'Normal 400', 'cheshalo' ) => 400,
						esc_html__( 'Medium 500', 'cheshalo' ) => 500,
						esc_html__( 'Semi-Bold 600', 'cheshalo' ) => 600,
						esc_html__( 'Bold 700', 'cheshalo' ) => 700,
						esc_html__( 'Extra-Bold 800', 'cheshalo' ) => 800,
						esc_html__( 'Ultra-Bold 900', 'cheshalo' ) => 900,
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_responsive_size',
					'heading' => esc_html__( 'Custom size', 'cheshalo' ),
					'param_name' => 'title_font_size',
					'css_args' => array(
						'font-size' => array(
							' .cheshalo-title-container',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column', 
				),
				array(
					'type' => 'cheshalo_responsive_size',
					'heading' => esc_html__( 'Custom line height', 'cheshalo' ),
					'param_name' => 'title_line_height',
					'css_args' => array(
						'line-height' => array(
							' .cheshalo-title-container',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column', 
				),
				array(
					'type' => 'cheshalo_empty_space',
					'param_name' => 'cheshalo_empty_space',
				),
				array(
					'type' => 'cheshalo_dropdown',
					'heading' => esc_html__( 'Predefined color scheme', 'cheshalo' ),
					'param_name' => 'color',
					'value' => cheshalo_section_title_color_variation(),
					'style' => array(
						'default' => '#989898',
						'primary' => cheshalo_get_color_value( 'primary-color', '#7eb934' ),
						'alt' => cheshalo_get_color_value( 'secondary-color', '#fbbc34' ),
						'black' => '#2d2a2a',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Custom title color', 'cheshalo' ),
					'param_name' => 'title_custom_color',
					'css_args' => array(
						'color' => array(
							' .cheshalo-title-container',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				cheshalo_title_gradient_picker(),
				/**
				* Layout
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout_divider'
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Title align', 'cheshalo' ),
					'param_name' => 'align',
				    'value' => array( 
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images_value' => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left' => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right' => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'std' => 'center',
					'wood_tooltip' => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				array(
					'type' => 'cheshalo_slider',
					'heading' => esc_html__( 'Title width', 'cheshalo' ),
					'param_name' => 'title_width',
					'min' => '10',
					'max' => '100',
					'step' => '10',
					'default' => '100',
					'units' => '%',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Title style', 'cheshalo' ),
					'param_name' => 'style',
					'value' => array( 
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Simple', 'cheshalo' ) => 'simple',
						esc_html__( 'Bordered', 'cheshalo' ) => 'bordered',
						esc_html__( 'Underline', 'cheshalo' ) => 'underlined',
						esc_html__( 'Underline 2', 'cheshalo' ) => 'underlined-2',
						esc_html__( 'Shadow', 'cheshalo' ) => 'shadow',
						esc_html__( 'With image', 'cheshalo' ) => 'image'
					),
					'images_value' => array(
						'default' => CHESHALO_ASSETS_IMAGES . '/settings/title-style/default.png',
						'simple' => CHESHALO_ASSETS_IMAGES . '/settings/title-style/simple.png',
						'bordered' => CHESHALO_ASSETS_IMAGES . '/settings/title-style/bordered.png',
						'underlined' => CHESHALO_ASSETS_IMAGES . '/settings/title-style/underlined.png',
						'underlined-2' => CHESHALO_ASSETS_IMAGES . '/settings/title-style/underlined-2.png',
						'shadow' => CHESHALO_ASSETS_IMAGES . '/settings/title-style/shadow.png',
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/title-style/image.png',
					),
				),
				/**
				* Image
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Image', 'cheshalo' ),
					'param_name' => 'image_divider',
					'dependency' => array(
						'element' => 'style',
						'value' => array( 'image' )
					)
				),
				array(
					'type' => 'attach_image',
					'heading' => esc_html__( 'Image', 'cheshalo' ),
					'param_name' => 'image',
					'value' => '',
					'hint' => esc_html__( 'Select image from media library.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'dependency' => array(
						'element' => 'style',
						'value' => array( 'image' )
					)
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Image size', 'cheshalo' ),
					'param_name' => 'img_size',
					'hint' => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'dependency' => array(
						'element' => 'style',
						'value' => array( 'image' )
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
					
				),
				/**
				* Extra
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Title tag', 'cheshalo' ),
					'param_name' => 'tag',
					'value' => array(
						'h1' => 'h1',
						'h2' => 'h2',
						'h3' => 'h3',
						'h4' => 'h4',
						'h5' => 'h5',
						'h6' => 'h6',
						'p' => 'p',
						'div' => 'div',
						'span' => 'span',
					),
					'std' => 'h4',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				( function_exists( 'vc_map_add_css_animation' ) ) ? vc_map_add_css_animation( true ) : '',
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
					// 'edit_field_class' => 'vc_col-xs-12 vc_column cheshalo-vc-no-wrap',
				),
				/**
				* Subtitle
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Subtitle', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle_divider'
				),
				array(
					'type' => 'textarea',
					'heading' => esc_html__( 'Subtitle', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle'
				),
				array(
					'type' => 'cheshalo_responsive_size',
					'heading' => esc_html__( 'Font Size', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle_font_size',
					'css_args' => array(
						'font-size' => array(
							' .title-subtitle',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_responsive_size',
					'heading' => esc_html__( 'Line height', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle_line_height_size',
					'css_args' => array(
						'line-height' => array(
							' .title-subtitle',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_empty_space',
					'param_name' => 'cheshalo_empty_space',
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Font', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle_font',
					'value' => array(
						$default_font_subtitle => 'default',
						$alt_font_subtitle => 'alt'
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Font weight', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle_font_weight',
					'value' => array(
						'' => '',
						esc_html__( 'Ultra-Light 100', 'cheshalo' ) => 100,
						esc_html__( 'Light 200', 'cheshalo' ) => 200,
						esc_html__( 'Book 300', 'cheshalo' ) => 300,
						esc_html__( 'Normal 400', 'cheshalo' ) => 400,
						esc_html__( 'Medium 500', 'cheshalo' ) => 500,
						esc_html__( 'Semi-Bold 600', 'cheshalo' ) => 600,
						esc_html__( 'Bold 700', 'cheshalo' ) => 700,
						esc_html__( 'Extra-Bold 800', 'cheshalo' ) => 800,
						esc_html__( 'Ultra-Bold 900', 'cheshalo' ) => 900,
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Custom color', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle_color',
					'css_args' => array(
						'color' => array(
							' .title-subtitle',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Background color', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle_bg_color',
					'css_args' => array(
						'background-color' => array(
							' .title-subtitle',
						),
					),
					'dependency' => array(
						'element' => 'subtitle_style',
						'value' => array( 'background' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Style', 'cheshalo' ),
					'group' => esc_html__( 'Subtitle', 'cheshalo' ),
					'param_name' => 'subtitle_style',
					'value' => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Background', 'cheshalo' ) => 'background'
					),
					'images_value' => array(
						'default' => CHESHALO_ASSETS_IMAGES . '/settings/subtitle-style/default.png',
						'background' => CHESHALO_ASSETS_IMAGES . '/settings/subtitle-style/background.png',
					),
					'edit_field_class' => 'vc_col-sm-8 vc_column',
				),
				/**
				* Text after title
				*/
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Text', 'cheshalo' ),
					'group' => esc_html__( 'Text', 'cheshalo' ),
					'param_name' => 'text_divider'
				),
				array(
					'type' => 'textarea',
					'heading' => esc_html__( 'Text after title', 'cheshalo' ),
					'group' => esc_html__( 'Text', 'cheshalo' ),
					'param_name' => 'after_title'
				),
				array(
					'type' => 'cheshalo_responsive_size',
					'heading' => esc_html__( 'Size', 'cheshalo' ),
					'group' => esc_html__( 'Text', 'cheshalo' ),
					'param_name' => 'after_font_size',
					'css_args' => array(
						'font-size' => array(
							' .title-after_title',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_responsive_size',
					'heading' => esc_html__( 'Line height', 'cheshalo' ),
					'group' => esc_html__( 'Text', 'cheshalo' ),
					'param_name' => 'after_line_height_size',
					'css_args' => array(
						'line-height' => array(
							' .title-after_title',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_colorpicker',
					'heading' => esc_html__( 'Color', 'cheshalo' ),
					'group' => esc_html__( 'Text', 'cheshalo' ),
					'param_name' => 'after_color',
					'css_args' => array(
						'color' => array(
							' .title-after_title',
						),
					),
				),
				/**
				* Custom sizes
				*/
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Desktop text size ( > 1024px )', 'cheshalo' ),
					'param_name' => 'desktop_text_size',
					'hint' => esc_html__( 'Only number without px.', 'cheshalo' ),
					'group' => esc_html__( 'Custom size (deprecated)', 'cheshalo' ),
					'dependency' => array(
						'element' => 'size',
						'value' => array( 'custom' )
					) 
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Tablet text size ( < 1024px )', 'cheshalo' ),
					'param_name' => 'tablet_text_size',
					'hint' => esc_html__( 'Only number without px.', 'cheshalo' ),
					'group' => esc_html__( 'Custom size (deprecated)', 'cheshalo' ),
					'dependency' => array(
						'element' => 'size',
						'value' => array( 'custom' )
					) 	
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Mobile text size ( < 767px )', 'cheshalo' ),
					'param_name' => 'mobile_text_size',
					'hint' => esc_html__( 'Only number without px.', 'cheshalo' ),
					'group' => esc_html__( 'Custom size (deprecated)', 'cheshalo' ),
					'dependency' => array(
						'element' => 'size',
						'value' => array( 'custom' )
					) 
				),
				array(
					'type' => 'css_editor',
					'heading' => esc_html__( 'CSS box', 'cheshalo' ),
					'param_name' => 'css',
					'group' => esc_html__( 'Design Options', 'cheshalo' )
				),
				/**
				 * Advanced.
				 */
				function_exists( 'cheshalo_get_vc_animation_map' ) ? cheshalo_get_vc_animation_map() : '',
				function_exists( 'cheshalo_get_vc_animation_delay_map' ) ? cheshalo_get_vc_animation_delay_map() : '',
				function_exists( 'cheshalo_get_vc_animation_duration_map' ) ? cheshalo_get_vc_animation_duration_map() : '',
			),
		) );
	}
	add_action( 'vc_before_init', 'cheshalo_vc_map_title' );
}
