<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
}

/**
 * ------------------------------------------------------------------------------------------------
 * Function returns quick view of the product by ID
 * ------------------------------------------------------------------------------------------------
 */

if( ! function_exists( 'cheshalo_quick_view' ) ) {
	function cheshalo_quick_view($id = false) {
		if( isset($_GET['id']) ) {
			$id = sanitize_text_field( (int) $_GET['id'] );
		}
		if( ! $id || ! cheshalo_woocommerce_installed() ) {
			return;
		}

		global $post, $product;


		$args = apply_filters(
			'cheshalo_quick_view_posts_args',
			array(
				'post__in'  => array( $id ),
				'post_type' => 'product',
			)
		);

		$quick_posts = get_posts( $args );

		$quick_view_variable = cheshalo_get_opt( 'quick_view_variable' );
		$quick_view_layout = ( cheshalo_get_opt( 'quick_view_layout' ) ) ? cheshalo_get_opt( 'quick_view_layout' ) : 'horizontal';

		echo '<div class="mfp-with-anim wd-popup popup-quick-view">';

		foreach( $quick_posts as $post ) :
			setup_postdata($post);
			$product = wc_get_product($post);
        	remove_action( 'woocommerce_single_product_summary', 'cheshalo_before_compare_button', 33 );
        	remove_action( 'woocommerce_single_product_summary', 'cheshalo_add_to_compare_single_btn', 33 );
			remove_action( 'woocommerce_single_product_summary', 'cheshalo_after_compare_button', 37 );
			
			if ( cheshalo_get_opt( 'attr_after_short_desc' ) ) {
				add_action( 'woocommerce_single_product_summary', 'cheshalo_display_product_attributes', 21 );
				add_filter( 'woocommerce_product_tabs', 'cheshalo_remove_additional_information_tab', 98 );
			}
			
			// Remove wishlist.
			remove_action( 'woocommerce_single_product_summary', array( XTS\WC_Wishlist\UI::get_instance(), 'add_to_wishlist_single_btn' ), 33 );
			
			//Remove before and after add to cart button text
			remove_action( 'woocommerce_single_product_summary', 'cheshalo_before_add_to_cart_area', 25 );
			remove_action( 'woocommerce_single_product_summary', 'cheshalo_after_add_to_cart_area', 31 );
			
        	remove_action( 'woocommerce_before_single_product', 'wc_print_notices', 10 );

        	// Add brand image
        	add_action( 'woocommerce_single_product_summary', 'cheshalo_product_brand', 8 );

        	// Disable add to cart button for catalog mode
			if( cheshalo_get_opt( 'catalog_mode' ) ) {
				remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
			} elseif( ! $quick_view_variable ) {
				// If no needs to show variations
				remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
				add_action( 'woocommerce_single_product_summary', 'woocommerce_template_loop_add_to_cart', 30 );
			}

			if( cheshalo_get_opt( 'product_share' ) ) add_action( 'woocommerce_single_product_summary', 'cheshalo_product_share_buttons', 45 );
			get_template_part('woocommerce/content', 'quick-view-' . $quick_view_layout );
		endforeach;

		echo '</div>';

		wp_reset_postdata(); 

		die();
	}

	add_action( 'wp_ajax_cheshalo_quick_view', 'cheshalo_quick_view' );
	add_action( 'wp_ajax_nopriv_cheshalo_quick_view', 'cheshalo_quick_view' );

}

if( ! function_exists( 'cheshalo_product_images_slider' ) ) {
	function cheshalo_product_images_slider() {
		wc_get_template( 'quick-view/product-images.php' );
	}
}

/**
 * ------------------------------------------------------------------------------------------------
 * Quick View button
 * ------------------------------------------------------------------------------------------------
 */

if( ! function_exists( 'cheshalo_quick_view_btn' ) ) {
	function cheshalo_quick_view_btn( $id = false ) {
		if( ! $id ) $id = get_the_ID();
		cheshalo_enqueue_js_library( 'owl' );
		cheshalo_enqueue_js_library( 'magnific' );
		cheshalo_enqueue_inline_style( 'mfp-popup' );
		cheshalo_enqueue_js_script( 'product-images-gallery' );
		cheshalo_enqueue_js_script( 'quick-view' );
		cheshalo_enqueue_js_library( 'tooltips' );
		cheshalo_enqueue_js_script( 'btns-tooltips' );
		cheshalo_enqueue_js_script( 'swatches-variations' );
		cheshalo_enqueue_js_script( 'add-to-cart-all-types' );
		cheshalo_enqueue_js_script( 'woocommerce-quantity' );
		wp_enqueue_script( 'wc-add-to-cart-variation' );
		wp_enqueue_script( 'imagesloaded' );

		if ( cheshalo_get_opt( 'quick_view' ) ): ?>
			<div class="quick-view wd-action-btn wd-style-icon wd-quick-view-icon<?php echo cheshalo_get_old_classes( ' wd-quick-view-btn' ); ?>">
				<a 
					href="<?php echo esc_url( get_the_permalink( $id ) ); ?>" 
					class="open-quick-view quick-view-button"
					data-id="<?php echo esc_attr( $id ); ?>"><?php esc_html_e( 'Quick view', 'cheshalo' ); ?></a>
			</div>
		<?php endif;
	}
}
