<?php

if ( ! function_exists( 'cheshalo_get_sticky_toolbar_fields' ) ) {
	/**
	 * All available fields for Theme Settings sorter option.
	 *
	 * @since 3.6
	 */
	function cheshalo_get_sticky_toolbar_fields( $new = false ) {

		if ( $new ) {
			$options = array(
				'shop' => array(
					'name'  => esc_html__( 'Shop page', 'cheshalo' ),
					'value' => 'shop',
				),
				'sidebar' => array(
					'name'  => esc_html__( 'Off canvas sidebar', 'cheshalo' ),
					'value' => 'sidebar',
				),
				'wishlist' => array(
					'name'  => esc_html__( 'Wishlist', 'cheshalo' ),
					'value' => 'wishlist',
				),
				'cart' => array(
					'name'  => esc_html__( 'Cart', 'cheshalo' ),
					'value' => 'cart',
				),
				'account' => array(
					'name'  => esc_html__( 'My account', 'cheshalo' ),
					'value' => 'account',
				),
				'mobile' => array(
					'name'  => esc_html__( 'Mobile menu', 'cheshalo' ),
					'value' => 'mobile',
				),
				'home' => array(
					'name'  => esc_html__( 'Home page', 'cheshalo' ),
					'value' => 'home',
				),
				'blog' => array(
					'name'  => esc_html__( 'Blog page', 'cheshalo' ),
					'value' => 'blog',
				),
				'compare' => array(
					'name'  => esc_html__( 'Compare', 'cheshalo' ),
					'value' => 'compare',
				),
				'link_1' => array(
					'name'  => esc_html__( 'Button [1]', 'cheshalo' ),
					'value' => 'link_1',
				),
				'link_2' => array(
					'name'  => esc_html__( 'Button [2]', 'cheshalo' ),
					'value' => 'link_2',
				),
				'link_3' => array(
					'name'  => esc_html__( 'Button [3]', 'cheshalo' ),
					'value' => 'link_3',
				),
				'link_4' => array(
					'name'  => esc_html__( 'Button [4]', 'cheshalo' ),
					'value' => 'link_4',
				),
				'link_5' => array(
					'name'  => esc_html__( 'Button [5]', 'cheshalo' ),
					'value' => 'link_5',
				),
			);

			if ( apply_filters( 'cheshalo_toolbar_search', false ) ) {
				$options['search'] = array(
					'name'  => esc_html__( 'Search', 'cheshalo' ),
					'value' => 'search',
				);
			}

			return $options;
		}

		$fields = array(
			'enabled'  => array(
				'shop'     => esc_html__( 'Shop page', 'cheshalo' ),
				'sidebar'  => esc_html__( 'Off canvas sidebar', 'cheshalo' ),
				'wishlist' => esc_html__( 'Wishlist', 'cheshalo' ),
				'cart'     => esc_html__( 'Cart', 'cheshalo' ),
				'account'  => esc_html__( 'My account', 'cheshalo' ),
			),
			'disabled' => array(
				'mobile'   => esc_html__( 'Mobile menu', 'cheshalo' ),
				'home'     => esc_html__( 'Home page', 'cheshalo' ),
				'blog'     => esc_html__( 'Blog page', 'cheshalo' ),
				'compare'  => esc_html__( 'Compare', 'cheshalo' ),
				'link_1'   => esc_html__( 'Button [1]', 'cheshalo' ),
				'link_2'   => esc_html__( 'Button [2]', 'cheshalo' ),
				'link_3'   => esc_html__( 'Button [3]', 'cheshalo' ),
				'link_4'   => esc_html__( 'Button [4]', 'cheshalo' ),
				'link_5'   => esc_html__( 'Button [5]', 'cheshalo' ),
			),
		);

		if ( apply_filters( 'cheshalo_toolbar_search', false ) ) {
			$fields['disabled']['search'] = esc_html__( 'Search', 'cheshalo' );
		}

		return $fields;
	}
}

if ( ! function_exists( 'cheshalo_sticky_toolbar_template' ) ) {
	/**
	 * Sticky toolbar template
	 *
	 * @since 3.6
	 */
	function cheshalo_sticky_toolbar_template() {
		$fields  = cheshalo_get_opt( 'sticky_toolbar_fields' );
		$classes = '';

		if ( isset( $fields['enabled']['placebo'] ) ) {
			unset( $fields['enabled']['placebo'] );
		}

		$enabled_fields = class_exists( 'XTS\Options' ) ? $fields : $fields['enabled'];

		if ( ! cheshalo_get_opt( 'sticky_toolbar' ) || ! $enabled_fields ) {
			return;
		}

		if ( cheshalo_get_opt( 'sticky_toolbar_label' ) ) {
			$classes .= ' wd-toolbar-label-show';
			$classes .= cheshalo_get_old_classes( ' cheshalo-toolbar-label-show' );
		}

		cheshalo_enqueue_inline_style( 'bottom-toolbar' );
		cheshalo_enqueue_inline_style( 'header-elements-base' );

		$classes .= cheshalo_get_old_classes( ' cheshalo-toolbar' );

		?>
		<div class="wd-toolbar<?php echo esc_attr( $classes ); ?>">
			<?php
			foreach ( $enabled_fields as $key => $value ) {
				$key = class_exists( 'XTS\Options' ) ? $value : $key;
				switch ( $key ) {
					case 'wishlist':
						cheshalo_sticky_toolbar_wishlist_template();
						break;
					case 'cart':
						cheshalo_sticky_toolbar_cart_template();
						break;
					case 'compare':
						cheshalo_sticky_toolbar_compare_template();
						break;
					case 'search':
						cheshalo_sticky_toolbar_search_template();
						break;
					case 'account':
						cheshalo_sticky_toolbar_account_template();
						break;
					case 'mobile':
						cheshalo_sticky_toolbar_mobile_menu_template();
						break;
					case 'sidebar':
						cheshalo_sticky_sidebar_button( false, true );
						break;
					case 'link_1';
					case 'link_2';
					case 'link_3';
					case 'link_4';
					case 'link_5';
						cheshalo_sticky_toolbar_custom_link_template( $key );
						break;
					case 'home';
					case 'blog';
					case 'shop':
						cheshalo_sticky_toolbar_page_link_template( $key );
						break;
				}
			}
			?>
		</div>
		<?php

	}

	add_action( 'wp_footer', 'cheshalo_sticky_toolbar_template' );
}

if ( ! function_exists( 'cheshalo_sticky_toolbar_wishlist_template' ) ) {
	/**
	 * Sticky toolbar wishlist template
	 *
	 * @since 3.6
	 */
	function cheshalo_sticky_toolbar_wishlist_template() {
		if ( ! cheshalo_woocommerce_installed() || ! cheshalo_get_opt( 'wishlist' ) ) {
			return;
		}

		$settings      = whb_get_settings();
		$product_count = false;
		$classes       = '';

		if ( isset( $settings['wishlist']['hide_product_count'] ) ) {
			$product_count = ! $settings['wishlist']['hide_product_count'];
		}

		if ( ! $product_count ) {
			$classes .= ' without-product-count';
		}

		cheshalo_enqueue_js_script( 'wishlist' );

		?>
		<div class="wd-header-wishlist wd-tools-element<?php echo esc_attr( $classes ); ?>" title="<?php echo esc_attr__( 'My wishlist', 'cheshalo' ); ?>">
			<a href="<?php echo esc_url( cheshalo_get_whishlist_page_url() ); ?>">
				<span class="wd-tools-icon">
					<?php if ( $product_count ) : ?>
						<span class="wd-tools-count">
							<?php echo esc_html( cheshalo_get_wishlist_count() ); ?>
						</span>
					<?php endif; ?>
				</span>
				<span class="wd-toolbar-label">
					<?php echo esc_html_x( 'Wishlist', 'toolbar', 'cheshalo' ); ?>
				</span>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'cheshalo_sticky_toolbar_cart_template' ) ) {
	/**
	 * Sticky toolbar cart template
	 *
	 * @since 3.6
	 */
	function cheshalo_sticky_toolbar_cart_template() {
		if ( ! cheshalo_woocommerce_installed() || ( ! is_user_logged_in() && cheshalo_get_opt( 'login_prices' ) ) ) {
			return;
		}

		$settings = whb_get_settings();
		$opener   = false;
		$classes  = '';

		if ( isset( $settings['cart']['position'] ) ) {
			$opener = $settings['cart']['position'] == 'side';
		}

		if ( $opener ) {
			$classes .= ' cart-widget-opener';
		}

		cheshalo_enqueue_inline_style( 'header-cart' );

		$classes .= cheshalo_get_old_classes( ' cheshalo-shopping-cart' );

		?>
		<div class="wd-header-cart wd-design-5 wd-tools-element<?php echo esc_attr( $classes ); ?>" title="<?php echo esc_attr__( 'My cart', 'cheshalo' ); ?>">
			<a href="<?php echo esc_url( wc_get_cart_url() ); ?>">
				<span class="wd-tools-icon wd-icon-alt">
					<?php cheshalo_cart_count(); ?>
				</span>
				<span class="wd-toolbar-label">
					<?php esc_html_e( 'Cart', 'cheshalo' ); ?>
				</span>
			</a>
		</div>
		<?php
	}
}


if ( ! function_exists( 'cheshalo_sticky_toolbar_compare_template' ) ) {
	/**
	 * Sticky toolbar compare template
	 *
	 * @since 3.6
	 */
	function cheshalo_sticky_toolbar_compare_template() {
		if ( ! cheshalo_woocommerce_installed() || ! cheshalo_get_opt( 'compare' ) ) {
			return;
		}

		$settings      = whb_get_settings();
		$product_count = false;
		$classes       = '';

		if ( isset( $settings['compare']['hide_product_count'] ) ) {
			$product_count = ! $settings['compare']['hide_product_count'];
		}

		if ( ! $product_count ) {
			$classes .= ' without-product-count';
		}

		?>
		<div class="wd-header-compare wd-tools-element<?php echo esc_attr( $classes ); ?>" title="<?php echo esc_attr__( 'Compare products', 'cheshalo' ); ?>">
			<a href="<?php echo esc_url( cheshalo_get_compare_page_url() ); ?>">
				<span class="wd-tools-icon">
					<?php if ( $product_count ) : ?>
						<span class="wd-tools-count"><?php echo cheshalo_get_compare_count(); ?></span>
					<?php endif; ?>
				</span>
				<span class="wd-toolbar-label">
					<?php esc_html_e( 'Compare', 'cheshalo' ); ?>
				</span>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'cheshalo_sticky_toolbar_search_template' ) ) {
	/**
	 * Sticky toolbar search template
	 *
	 * @since 3.6
	 */
	function cheshalo_sticky_toolbar_search_template() {
		cheshalo_enqueue_js_script( 'mobile-search' );
		?>
		<div class="wd-header-search wd-header-search-mobile<?php echo cheshalo_get_old_classes( ' mobile-search-icon search-button' ); ?>">
			<a href="#" rel="nofollow">
				<span class="wd-tools-icon<?php echo cheshalo_get_old_classes( ' search-button-icon' ); ?>"></span>
				<span class="wd-toolbar-label">
					<?php esc_html_e( 'Search', 'cheshalo' ); ?>
				</span>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'cheshalo_sticky_toolbar_account_template' ) ) {
	/**
	 * Sticky toolbar account template
	 *
	 * @since 3.6
	 */
	function cheshalo_sticky_toolbar_account_template() {
		if ( ! cheshalo_woocommerce_installed() ) {
			return;
		}

		$settings = whb_get_settings();
		$is_side  = isset( $settings['account'] ) && 'side' === $settings['account']['form_display'] && $settings['account']['login_dropdown'];
		$classes  = '';

		if ( ! is_user_logged_in() && $is_side ) {
			cheshalo_enqueue_js_script( 'login-sidebar' );
			$classes .= ' login-side-opener';
		}

		cheshalo_enqueue_inline_style( 'header-my-account' );

		?>
		<div class="wd-header-my-account wd-tools-element wd-style-icon <?php echo esc_attr( $classes ); ?>">
			<a href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>">
				<span class="wd-tools-icon"></span>
				<span class="wd-toolbar-label">
					<?php echo esc_html_x( 'My account', 'toolbar', 'cheshalo' ); ?>
				</span>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'cheshalo_sticky_toolbar_page_link_template' ) ) {
	/**
	 * Sticky toolbar page link template
	 *
	 * @since 3.6
	 */
	function cheshalo_sticky_toolbar_page_link_template( $key ) {
		$url = '';

		switch ( $key ) {
			case 'blog':
				$url  = get_permalink( get_option( 'page_for_posts' ) );
				$text = esc_html__( 'Blog', 'cheshalo' );
				break;
			case 'home':
				$url  = get_home_url();
				$text = esc_html__( 'Home', 'cheshalo' );
				break;
			case 'shop':
				$url  = cheshalo_woocommerce_installed() ? get_permalink( wc_get_page_id( 'shop' ) ) : get_home_url();
				$text = esc_html__( 'Shop', 'cheshalo' );
				break;
		}

		$classes = '';

		$classes .= cheshalo_get_old_classes( ' cheshalo-toolbar-' . $key );
		$classes .= cheshalo_get_old_classes( ' cheshalo-toolbar-item' );

		?>
		<div class="wd-toolbar-<?php echo esc_attr( $key ); ?> wd-toolbar-item wd-tools-element<?php echo esc_attr( $classes ); ?>">
			<a href="<?php echo esc_url( $url ); ?>">
				<span class="wd-tools-icon"></span>
				<span class="wd-toolbar-label">
					<?php echo $text; ?>
				</span>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'cheshalo_sticky_toolbar_custom_link_template' ) ) {
	/**
	 * Sticky toolbar custom link template
	 *
	 * @since 3.6
	 *
	 * @param string $key Key.
	 */
	function cheshalo_sticky_toolbar_custom_link_template( $key ) {
		cheshalo_lazy_loading_deinit( true );

		$wrapper_classes = '';
		$url             = cheshalo_get_opt( $key . '_url' );
		$text            = cheshalo_get_opt( $key . '_text' );
		$icon            = cheshalo_get_opt( $key . '_icon' );

		$wrapper_classes .= isset( $icon['id'] ) && $icon['id'] ? ' wd-tools-custom-icon' : '';

		$wrapper_classes .= cheshalo_get_old_classes( ' cheshalo-toolbar-item cheshalo-toolbar-link' );

		?>
		<?php if ( $url && $text ) : ?>
			<div class="wd-toolbar-link wd-tools-element wd-toolbar-item<?php echo esc_attr( $wrapper_classes ); ?>">
				<a href="<?php echo esc_url( $url ); ?>">
					<span class="wd-toolbar-icon wd-tools-icon wd-icon wd-custom-icon">
						<?php if ( isset( $icon['id'] ) && $icon['id'] ) : ?>
							<?php echo wp_get_attachment_image( $icon['id'] ); ?>
						<?php endif; ?>
					</span>

					<span class="wd-toolbar-label">
						<?php echo esc_html( $text ); ?>
					</span>
				</a>
			</div>
		<?php endif; ?>
		<?php

		cheshalo_lazy_loading_init();
	}
}

if ( ! function_exists( 'cheshalo_sticky_toolbar_mobile_menu_template' ) ) {
	/**
	 * Sticky toolbar mobile menu template
	 *
	 * @since 3.6
	 */
	function cheshalo_sticky_toolbar_mobile_menu_template() {
		?>
		<div class="wd-header-mobile-nav whb-wd-header-mobile-nav mobile-style-icon wd-tools-element<?php echo cheshalo_get_old_classes( ' cheshalo-burger-icon' ); ?>">
			<a href="#" rel="nofollow">
				<span class="wd-tools-icon<?php echo cheshalo_get_old_classes( ' cheshalo-burger' ); ?>"></span>
				<span class="wd-toolbar-label">
					<?php esc_html_e( 'Menu', 'cheshalo' ); ?>
				</span>
			</a>
		</div>
		<?php
	}
}
